<?php

namespace App\Exports;

use App\Models\CashierSale;
use App\Models\Deposit;
use App\Models\drivewayAccount;
use App\Models\DrivewaySheet;
use App\Models\FuelInfo;
use App\Models\FuelStock;
use App\Models\Header;
use App\Models\Sale;
use App\Models\SheelCard;
use App\Models\SiteRegister;
use App\Models\SpeedPoint;
use Illuminate\Contracts\View\View;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\FromView;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;

class DrivewayExport implements FromView,ShouldAutoSize
{
    /**
    * @return \Illuminate\Contracts\View\View;
    */
    public function view(): View
    {
        $date = request('date');
        $site = SiteRegister::with('pumps')->where('id',session()->get('branch_id'))->first();
        $pumps = collect();
        $fuels = collect();
        if(!empty($site)){
            $pumps = $site->pumps->where('is_fake',0)->unique();
            $fuels = $site->fuels->where('is_shell',0)->unique()->pluck('fuel_name','id');
        }
        $drivesheet = DrivewaySheet::where('branch_id',session()->get('branch_id'))->whereDate('date',$date)->get();

        $fuelprices = FuelInfo::where('branch_id',session()->get('branch_id'))->whereDate('effective_from','<=',$date)->whereNull('effective_to')->orWhereDate('effective_to','>',$date)->get();
        $fuelstock = FuelStock::where('branch_id',session()->get('branch_id'))->whereDate('date',$date)->get();
        $shopsale = Sale::query()->with('financialCategory.header')->where('branch_id',session()->get('branch_id'))
                            ->whereDate('date',$date)
                            ->whereHas('financialCategory.header', function($query) {
                                $query->where('code','cat3');})->get();
        $fuelsale = Sale::query()->with('financialCategory.header')->where('branch_id',session()->get('branch_id'))
                            ->whereDate('date',$date)
                            ->whereHas('financialCategory.header', function($query) {
                                $query->where('code','cat26');})->get();
        $shell = SheelCard::where('branch_id',session()->get('branch_id'))->whereDate('date',$date)->select('date','amount',\DB::raw("SUM(amount) as total_amount"))->groupBy('date')->first();
        $driveway_account = drivewayAccount::where('branch_id',session()->get('branch_id'))->whereDate('date',$date)->select('date','amount',\DB::raw("SUM(amount) as total_amount"))->groupBy('date')->first();
        $speed = SpeedPoint::where('branch_id',session()->get('branch_id'))->whereDate('date',$date)
                                ->leftjoin('machines as m', 'm.id', '=', 'speed_points.reconcilation_type')
                                ->select('m.type','reconcilation_type','date',\DB::raw("SUM(amount) as total_amount"))->groupBy('m.type')->get();
        $cashiersale = CashierSale::with('financialcategory')->where('branch_id',session()->get('branch_id'))->whereDate('date',$date)->get();
        $category = Header::where('category_type','deposit')->get();
        $deposit = Deposit::with('financialCategory')
                            ->whereHas('financialCategory', function($query) {
                                $query->where('status','1');})
                            ->where('branch_id',session()->get('branch_id'))->whereDate('date',$date)->get();
        return view('exports.driveway',compact('drivesheet','fuelprices','pumps','fuels','date','fuelstock','shopsale','fuelsale','cashiersale','site','shell','driveway_account','speed','deposit','category'));
    }
}
