<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyAccountRequest;
use App\Http\Requests\StoreAccountRequest;
use App\Http\Requests\UpdateAccountRequest;
use App\Models\Account;
use App\Models\ShiftNo;
use App\Models\Suplier;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class AccountController extends Controller
{
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }
    public function index(Request $request)
    {
        abort_if(Gate::denies('cash_credit_account_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $start =  date('Y-m-d', strtotime(strtr($request->min, '/', '-')));
            $end = date('Y-m-d', strtotime(strtr($request->max, '/', '-')));
            $query = Account::query()->where('branch_id',$this->branch_id);
            if($request->min != null || $request->max != null ){
                $query = $query->whereDate('date','>=',date('Y-m-d',strtotime($start)))->whereDate('date','<=',date('Y-m-d',strtotime($end)));
            }
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');
            $table->addIndexColumn();

            $table->editColumn('actions', function ($row) {
                $viewGate = 'cash_credit_account_show';
                $editGate = 'cash_credit_account_edit';
                $deleteGate = 'cash_credit_account_delete';
                $crudRoutePart = 'accounts';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });
            $table->rawColumns(['actions', 'placeholder']);
            $table->editColumn('date',function($row){
                return date('d/m/Y',strtotime($row->date));
            });
            $table->editColumn('shift_no',function($row){
                return $row->shift ?  $row->shift->title : '';
            });

            $table->editColumn('company_name',function($row){
                return $row->supplier ?  $row->supplier->suplier : '';
            });

            return $table->make(true);
        }

        return view('admin.accounts.index');
    }

    public function create()
    {
        abort_if(Gate::denies('cash_credit_account_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $supplier = Suplier::where('branch_id',$this->branch_id)->where('type','Company')->get()->pluck('suplier','id')->prepend(trans('global.pleaseSelect'),'');
        $shift = ShiftNo::where('branch_id',$this->branch_id)->where('status',1)->get()->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');

        return view('admin.accounts.create',compact('supplier','shift'));
    }

    public function store(StoreAccountRequest $request)
    {
       if ($request->ajax()) {

        $shift = null;
        $company = null;
        $order_no = null;
        $veh_reg_no = null;
        $fleet_no = null;
        $d_name = null;

        foreach ($request->invoice_no as $key => $value) {

            // check shift
            if ($request->has('shift')) {
                foreach ($request->shift as $id => $val) {
                    if ($key == $id && $val != null) {
                        $shift = $request->shift[$key];
                    }
                }
            }

            // check company
            if ($request->has('company')) {
                foreach ($request->company as $id => $val) {
                    if ($key == $id && $val != null) {
                        $company = $request->company[$key];
                    }
                }
            }

            // check order_no
            if ($request->has('order_no')) {
                foreach ($request->order_no as $id => $val) {
                    if ($key == $id && $val != null) {
                        $order_no = $request->order_no[$key];
                    }
                }
            }

            // check veh reg no.
            if ($request->has('veh_reg_no')) {
                foreach ($request->veh_reg_no as $id => $val) {
                    if ($key == $id && $val != null) {
                        $veh_reg_no = $request->veh_reg_no[$key];
                    }
                }
            }

            // check feet_no
            if ($request->has('fleet_no')) {
                foreach ($request->fleet_no as $id => $val) {
                    if ($key == $id && $val != null) {
                        $fleet_no = $request->fleet_no[$key];
                    }
                }
            }

            // check d_name
            if ($request->has('d_name')) {
                foreach ($request->d_name as $id => $val) {
                    if ($key == $id && $val != null) {
                        $d_name = $request->d_name[$key];
                    }
                }
            }

             // check attachement is avilable
             if($request->hasFile('attachment'))
             {
                foreach ($request->attachment as $id => $val) {
                    if ($key == $id && $val != null) {
                        if ($file = $request->file('attachment')[$key]) {
                            $optimizePath = '../public/images/Account/';
                            if (!file_exists($optimizePath)) {
                                mkdir($optimizePath, 666, true);
                            }
                            $name = time() . '_Account_' . $file->getClientOriginalName();
                            $file->move($optimizePath, $name);
                            $attach = $name;
                        }
                    }
                }
             }

            $req_date = strtr($request->date,'/','-');
            $date = date('Y-m-d',strtotime($req_date));
            Account::create([
                'date' => $date,
                'shift_no' => $shift,
                'invoice_no' => $request->invoice_no[$key],
                'company_name' => $company,
                'amount' => $request->amount[$key],
                'order_no' => $order_no,
                'veh_reg_no' => $veh_reg_no,
                'fleet_no' => $fleet_no,
                'd_name' => $d_name,
                'branch_id' => $this->branch_id,
            ]);
        }

       }
       return response()->json(['success'=>true,'message'=>'Account added successfully!','url'=> route('admin.accounts.index')]);
    }

    public function edit(Account $account)
    {
        abort_if(Gate::denies('cash_credit_account_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $supplier = Suplier::where('branch_id',$this->branch_id)->where('type','Company')->get()->pluck('suplier','id')->prepend(trans('global.pleaseSelect'),'');
        $shift = ShiftNo::awhere('branch_id',$this->branch_id)->where('status',1)->get()->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');

        return view('admin.accounts.edit', compact('account','shift','supplier'));
    }

    public function update(UpdateAccountRequest $request, Account $account)
    {
        $request->has('shift_no') ? $shift = $request->shift_no : $shift = null;
        $request->has('company_name') ? $company = $request->company_name : $company = null;
        $request->has('order_no') ? $order_no = $request->order_no : $order_no = null;
        $request->has('veh_reg_no') ? $veh_reg_no = $request->veh_reg_no : $veh_reg_no = null;
        $request->has('fleet_no') ? $fleet_no = $request->fleet_no : $fleet_no = null;
        $request->has('d_name') ? $d_name = $request->d_name : $d_name = null;

        $req_date = strtr($request->date,'/','-');
        $date = date('Y-m-d',strtotime($req_date));

        $account->update([
                'date' => $date,
                'shift_no' => $shift,
                'invoice_no' => $request->invoice_no,
                'company_name' => $company,
                'amount' => $request->amount,
                'order_no' => $order_no,
                'veh_reg_no' => $veh_reg_no,
                'fleet_no' => $fleet_no,
                'd_name' => $d_name,
                'branch_id' => $this->branch_id,
        ]);

        toastr()->info('Account has been updated successfully!');
        return redirect()->route('admin.accounts.index');
    }

    public function show(Account $account)
    {
        abort_if(Gate::denies('cash_credit_account_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.accounts.show', compact('account'));
    }

    public function destroy(Account $account)
    {
        abort_if(Gate::denies('cash_credit_account_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $account->forceDelete();
        toastr()->error('Account has been deleted!');
        return back();
    }

    public function massDestroy(MassDestroyAccountRequest $request)
    {
        Account::whereIn('id', request('ids'))->forceDelete();

        toastr()->error('Account has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
