<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AccountInfo;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class AccountInfoController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('driveway_account_info_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $account_info_list = AccountInfo::all();
        return view('admin.accountInfo.index',compact('account_info_list'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('driveway_account_info_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'title' => 'required|string|max:40|unique:account_infos',
            'status' => 'nullable',
            'remarks' => 'nullable|string|max:80',
        ]);

        AccountInfo::create($request->all());
        toastr()->success('Account is created successfully!');
        return redirect()->route('admin.account-infos.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(AccountInfo $account_info)
    {
        abort_if(Gate::denies('driveway_account_info_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $account_info_list =  AccountInfo::all();
        return view('admin.accountInfo.index',compact('account_info_list','account_info'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, AccountInfo $account_info)
    {
        abort_if(Gate::denies('driveway_account_info_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'title' => 'required|string|max:40',
            'status' => 'nullable',
            'remarks' => 'nullable|string|max:80',
        ]);
        if ($request->has('status')) {
            $account_info->update($request->all());
        }
        else{
            $account_info->update([
                'title' => $request->title,
                'status' => 0,
                'remarks' => $request->remarks,
            ]);
        }
        toastr()->info('Account has been updated successfully!');
        return redirect()->route('admin.account-infos.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(AccountInfo $account_info)
    {
        abort_if(Gate::denies('driveway_account_info_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if(isset($account_info->driveway_account) && count($account_info->driveway_account) > 0){
            toastr()->error('It has associated data. Please delete that first!');
            return back();
        }
        $account_info->forceDelete();
        toastr()->error('Account has been deleted!');
        return back();
    }

    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('driveway_account_info_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
            'ids.*' => 'exists:account_infos,id',
        ]);

        foreach($request->ids as $id){
            $account_info = AccountInfo::find($id);
            $this->destroy($account_info);
        }
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
