<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyCashPurchaseRequest;
use App\Http\Requests\StoreCashPurchaseRequest;
use App\Http\Requests\UpdateCashPurchaseRequest;
use App\Models\BankAccount;
use App\Models\CashPurchase;
use App\Models\FinancialCategory;
use App\Models\Suplier;
use App\Models\Vat;
use Gate;
use DB;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class CashPurchaseController extends Controller
{
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }
    public function index(Request $request)
    {
        abort_if(Gate::denies('cash_purchase_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $start =  date('Y-m-d', strtotime(strtr($request->min, '/', '-')));
            $end = date('Y-m-d', strtotime(strtr($request->max, '/', '-')));
            $query = CashPurchase::query()->with(['suplier'])->where('branch_id',$this->branch_id);
            if($request->min != null || $request->max != null ){
                $query = $query->whereDate('date','>=',date('Y-m-d',strtotime($start)))->whereDate('date','<=',date('Y-m-d',strtotime($end)));
            }
            // $query = $query->select(sprintf('%s.*', (new CashPurchase())->table));
            $table = Datatables::of($query);
            $table->addIndexColumn();

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate = 'cash_purchase_show';
                $editGate = 'cash_purchase_edit';
                $deleteGate = 'cash_purchase_delete';
                $crudRoutePart = 'cash-purchases';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });

            $table->editColumn('date', function ($row) {
                return $row->date ? date('d/m/Y',strtotime($row->date)) : '';
            });

            $table->editColumn('invoice_no', function ($row) {
                return $row->invoice_no ? $row->invoice_no : '';
            });
            $table->addColumn('suplier', function ($row) {
                return $row->suplier ? $row->suplier->suplier : '';
            });

            $table->addColumn('bank_account', function ($row) {
                return $row->bankAccount ? $row->bankAccount->title : '';
            });

            $table->addColumn('header', function ($row) {
                $a = '<span class="badge badge-info">'.$row->cash_credit.'<span>';
                return $row->financialCategory ? $row->financialCategory->title."<br>".$a : $a;
            });

            $table->addColumn('vat', function ($row) {
                return $row->vat_value ? $row->vat_value : '';
            });
            $table->editColumn('amount', function ($row) {
                return $row->amount ? number_format($row->amount,2) : '';
            });

            $table->editColumn('amount_without_vat', function ($row) {
                return $row->amount_without_vat ? $row->amount_without_vat : '';
            });

            $table->rawColumns(['actions', 'placeholder', 'suplier','header','vat']);

            return $table->make(true);
        }

        return view('admin.cashPurchases.index');

    }

    public function create()
    {
        abort_if(Gate::denies('cash_purchase_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $supliers = Suplier::where('branch_id',$this->branch_id)->where('type','Supplier')->get()->pluck('suplier', 'id')->prepend(trans('global.pleaseSelect'), '');
        $bankAccounts = BankAccount::select('id', DB::raw("CONCAT(title,' ',IFNULL(account_no,'')) AS title1"))->get()->pluck('title1','id')->prepend(trans('global.pleaseSelect'),'');
        $vat = Vat::all()->where('status',1)->pluck('title', 'id')->prepend(trans('global.pleaseSelect'), '');
        $headers = FinancialCategory::with('header')
                            ->whereHas('header', function($query) {
                                $query->where('category_type','purchase');})
                            ->where('status','1')->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');

        return view('admin.cashPurchases.create', compact('supliers','bankAccounts','vat','headers'));
    }

    public function store(StoreCashPurchaseRequest $request)
    {
        // dd($request->input(),$request->file());
        $date1 = strtr($request->date, '/', '-');
        $eff_from = date('Y-m-d', strtotime($date1));
        foreach ($request->input('invoice_no') as $key => $value) {

            $amount_with_vat = (double)$request->total_amount[$key];
            $attach = '';
            $vat = null;
            $vat_value = null;
            $cash_credit = 'Cash';


            // check Cash_credit is null or not
            if($request->has('cash_credit')){
                foreach ($request->cash_credit as $id => $val) {
                    if ($key == $id && $val != null) {
                        $cash_credit = $request->cash_credit[$key];
                    }
                }
            }

            // check vat is applicable or not
            if ($request->has('vat')) {
                foreach ($request->vat as $id => $val) {
                    if ($key == $id && $val != null) {
                        $vat = $request->vat[$key];
                        $vat_value = Vat::find($request->vat[$key])->value;
                        $amount_with_vat = $request->total_amount[$key] + $request->total_amount[$key] * ($vat_value/100);
                    }
                }
            }

            // check attachement is avilable
            if($request->hasFile('attachment'))
            {
                foreach ($request->attachment as $id => $val) {
                    if ($key == $id && $val != null) {
                        if ($file = $request->file('attachment')[$key]) {
                            $optimizePath = '../public/images/CashPurchase/';
                            if (!file_exists($optimizePath)) {
                                mkdir($optimizePath, 666, true);
                            }
                            $name = time() . '_CashPurchase_' . $file->getClientOriginalName();
                            $file->move($optimizePath, $name);
                            $attach = $name;
                        }
                    }
                }
            }
            //  Stotering data
            $CashPurchase = CashPurchase::create([
                'branch_id' => session()->get('branch_id'),
                'vat_id' =>  $vat,
                'vat_value' => (double)$vat_value,
                'supplier_id' => $request->suplier[$key],
                'bank_account_id' => $request->bank_account,
                'financial_category_id' => $request->financial_category[$key],
                'date' => $eff_from,
                'invoice_no' => $request->invoice_no[$key],
                'cash_credit' => $cash_credit,
                'reference' => $request->reference[$key],
                'attachment' => $attach,
                'amount' => (double)$amount_with_vat,
                'amount_without_vat' => (double)$request->total_amount[$key],
            ]);
        }
        if($request->ajax()){
            return response()->json(['success'=>true,'message'=>'Purchase added successfully!','url'=> route('admin.cash-purchases.index')]);
        }
        return redirect()->route('admin.cash-purchases.index');
    }

    public function edit(CashPurchase $cashPurchase)
    {
        abort_if(Gate::denies('cash_purchase_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $supliers = Suplier::where('branch_id',$this->branch_id)->where('type','Supplier')->get()->pluck('suplier', 'id')->prepend(trans('global.pleaseSelect'), '');
        $bankAccount = BankAccount::select('id', DB::raw("CONCAT(title,' ',IFNULL(account_no,'')) AS title1"))->get()->pluck('title1','id')->prepend(trans('global.pleaseSelect'),'');
        $vat = Vat::all()->where('status',1)->pluck('title', 'id')->prepend(trans('global.pleaseSelect'), '');
        $headers = FinancialCategory::with('header')
                            ->whereHas('header', function($query) {
                                $query->where('category_type','purchase');})
                            ->where('status','1')->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');

        return view('admin.cashPurchases.edit', compact('cashPurchase','supliers','bankAccount','vat','headers'));
    }

    public function update(UpdateCashPurchaseRequest $request, CashPurchase $cashPurchase)
    {
        // dd($request->input());
        $date1 = strtr($request->date, '/', '-');
        $eff_from = date('Y-m-d', strtotime($date1));

        $amount_with_vat = $request->total_amount;
        $attach = '';
        $vat = null;
        $vat_value = null;

        if ($request->has('vat') && $request->vat != null)
        {
            $vat = $request->vat;
            $vat_value = Vat::find($request->vat)->value;
            $amount_with_vat = $request->total_amount + $request->total_amount * ($vat_value/100);
        }

        if($request->hasFile('attachment'))
            {
                if ($file = $request->file('attachment')) {
                    $optimizePath = '../public/images/cashExpense/';
                    if (!file_exists($optimizePath)) {
                        mkdir($optimizePath, 666, true);
                    }
                    $name = time() . '_cashexpense_' . $file->getClientOriginalName();
                    $file->move($optimizePath, $name);
                    $attach = $name;
                }

            }

        $cashPurchase->update([
            'branch_id' => session()->get('branch_id'),
            'vat_id' =>  $vat,
            'vat_value' => (double)$vat_value,
            'supplier_id' => $request->suplier,
            'bank_account_id' => $request->bank_account,
            'financial_category_id' => $request->financial_category,
            'date' => $eff_from,
            'invoice_no' => $request->invoice_no,
            'cash_credit' => $request->cash_credit,
            'reference' => $request->reference,
            'attachment' => $attach,
            'amount' => (double)$amount_with_vat,
            'amount_without_vat' => (double)$request->total_amount,
            'description' => $request->description,
        ]);

        toastr()->info('Purchase has been updated!');
        return redirect()->route('admin.cash-purchases.index');
    }

    public function show(CashPurchase $cashPurchase)
    {
        abort_if(Gate::denies('cash_purchase_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $cashPurchase->load('suplier');

        return view('admin.cashPurchases.show', compact('cashPurchase'));
    }

    public function destroy(CashPurchase $cashPurchase)
    {
        abort_if(Gate::denies('cash_purchase_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $cashPurchase->forceDelete();

        toastr()->error('Purchase has been deleted!');
        return back();
    }

    public function massDestroy(MassDestroyCashPurchaseRequest $request)
    {
        CashPurchase::whereIn('id', request('ids'))->forceDelete();

        toastr()->error('Purchase has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
