<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Currency;
use App\Models\CurrencyInfo;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Gate;

class CurrencyInfoController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('currency_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $currency_info_list = CurrencyInfo::all();
        $currency = Currency::all()->pluck('code','id')->prepend(trans('global.pleaseSelect'));
        return view('admin.currencyInfo.index',compact('currency_info_list','currency'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('currency_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'date' => 'required',
            'currency' => 'required|unique:currency_infos',
            'rate' => 'required|numeric',
        ]);
        $req_date = strtr($request->date,'/','-');
        $date = date('Y-m-d',strtotime($req_date));

        CurrencyInfo::create([
            'date' => $date,
            'currency' => $request->currency,
            'rate' => $request->rate,
        ]);
        toastr()->success("Currency is created successfully!");
        return redirect()->route('admin.currency-infos.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        abort_if(Gate::denies('currency_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $currency_info = CurrencyInfo::find($id);
        $currency_info_list = CurrencyInfo::all();
        $currency = Currency::all()->pluck('code','id')->prepend(trans('global.pleaseSelect'));
        return view('admin.currencyInfo.index',compact('currency_info_list','currency_info','currency'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        abort_if(Gate::denies('currency_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $currency_info = CurrencyInfo::find($id);
        $request->validate([
            'date' => 'required',
            'currency' => 'required',
            'rate' => 'required|numeric',
        ]);
        $req_date = strtr($request->date,'/','-');
        $date = date('Y-m-d',strtotime($req_date));

        $currency_info->update([
            'date' => $date,
            'currency' => $request->currency,
            'rate' => $request->rate,
        ]);
        toastr()->info('Currency has been updated successfully!');
        return redirect()->route('admin.currency-infos.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        abort_if(Gate::denies('currency_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $currency_info = CurrencyInfo::find($id);
        $currency_info->forceDelete();
        toastr()->error("Currency has been deleted successfully!");
        return redirect()->route('admin.currency-infos.index');
    }

    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('currency_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
            'ids.*' => 'exists:currency_infos,id',
        ]);

        foreach($request->ids as $id){
            $currency = CurrencyInfo::find($id);
            $currency->forceDelete();
        }
        toastr()->error('Currency has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
