<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyFuelStockRequest;
use App\Http\Requests\StoreFuelStockRequest;
use App\Http\Requests\UpdateFuelStockRequest;
use App\Models\Fuel;
use App\Models\FuelStock;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class FuelStockController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        abort_if(Gate::denies('fuel_stock_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = FuelStock::all();
            $table = DataTables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate = 'fuel_stock_show';
                $editGate = 'fuel_stock_edit';
                $deleteGate = 'fuel_stock_delete';
                $crudRoutePart = 'fuel-stocks';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });

            $table->editColumn('date', function ($row) {
                return $row->date ? $row->date : '';
            });

            $table->editColumn('fuel', function ($row) {
                return $row->fuel->fuel_name ? $row->fuel->fuel_name : '';
            });
            $table->addColumn('opening_stock', function ($row) {
                return $row->opening_stock ? $row->opening_stock : '';
            });

            $table->editColumn('purchase', function ($row) {
                return $row->purchase ? $row->purchase : '';
            });
            $table->editColumn('stock', function ($row) {
                return $row->stock ? $row->stock : '';
            });
            $table->editColumn('closing_dips', function ($row) {
                return $row->closing_dips ? $row->closing_dips : '';
            });

            $table->rawColumns(['actions', 'placeholder', 'fuelStock']);

            return $table->make(true);
        }

        return view('admin.fuelStocks.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        abort_if(Gate::denies('fuel_stock_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $fuel = Fuel::all();

        return view('admin.fuelStocks.create',['fuels' =>  $fuel]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreFuelStockRequest $request)
    {
        FuelStock::create($request->all());
        toastr()->success('Fuel stock is created successfully!');
        return redirect()->route('admin.fuel-stocks.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(FuelStock $fuelStock)
    {
        abort_if(Gate::denies('fuel_stock_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.fuelStocks.show', compact('fuelStock'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(FuelStock $fuelStock)
    {
        abort_if(Gate::denies('fuel_stock_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $fuels = Fuel::all();

        return view('admin.fuelStocks.edit', compact(['fuelStock','fuels']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateFuelStockRequest $request, FuelStock $fuelStock)
    {
        $fuelStock->update($request->all());
        toastr()->info('Fuel stock has been updated successfully!');
        return redirect()->route('admin.fuel-stocks.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(FuelStock $fuelStock)
    {
        $fuelStock->delete();
        toastr()->error('Fuel stock has been deleted!');
        return back();
    }

    public function massDestroy(MassDestroyFuelStockRequest $request)
    {
        FuelStock::whereIn('id', request('ids'))->delete();
        toastr()->error('Fuel stock has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
