<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Machine;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class MachineController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('machine_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $machine_list = Machine::all();
        return view('admin.machine.index',compact('machine_list'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('machine_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'title' => 'required|string|max:40|unique:machines',
            'type' => 'required',
            'remarks' => 'nullable|string|max:80',
        ]);

        Machine::create($request->all());
        toastr()->success('Machine is created successfully!');
        return redirect()->route('admin.machines.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Machine $machine)
    {
        abort_if(Gate::denies('machine_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $machine_list =  Machine::all();
        return view('admin.machine.index',compact('machine_list','machine'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Machine $machine)
    {
        abort_if(Gate::denies('machine_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'title' => 'required|string|max:40',
            'type' => 'required',
            'remarks' => 'nullable|string|max:80',
        ]);

        $machine->update($request->all());
        toastr()->info('Machine has been updated successfully!');
        return redirect()->route('admin.machines.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Machine $machine)
    {
        abort_if(Gate::denies('machine_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if(isset($machine->speedPoint) && count($machine->speedPoint) > 0){
            toastr()->error('It has associated data. Please delete that first!');
            return back();
        }
        $machine->forceDelete();
        toastr()->error('Machine has been deleted!');
        return back();
    }

    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('machine_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
            'ids.*' => 'exists:machines,id',
        ]);

        foreach($request->ids as $id){
            $machine = Machine::find($id);
            $this->destroy($machine);
        }
        // toastr()->error('Machine has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
