<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyPumpRequest;
use App\Http\Requests\StorePumpRequest;
use App\Http\Requests\UpdatePumpRequest;
use App\Imports\PumpImport;
use App\Models\Pump;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;
use Excel;

class PumpsController extends Controller
{
    use CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('pump_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        // $pumps = Pump::all();

        // return view('admin.pumps.index', compact('pumps'));
        if ($request->ajax()) {
            $query = Pump::all();
            $table = DataTables::of($query);
            $table->addIndexColumn();

            $table->addColumn('DT_RowId', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate = 'pump_show';
                $editGate = 'pump_edit';
                $deleteGate = 'pump_delete';
                $crudRoutePart = 'pumps';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });


            $table->editColumn('pump', function ($row) {
                return $row->pump ? $row->pump : '';
            });
            $table->addColumn('location', function ($row) {
                return $row->detail ? $row->detail : '';
            });

            $table->rawColumns(['actions', 'placeholder', 'pump']);

            return $table->make(true);
        }

        return view('admin.pumps.index');
    }

    public function create()
    {
        abort_if(Gate::denies('pump_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.pumps.create');
    }

    public function store(StorePumpRequest $request)
    {
        $pump = Pump::create($request->all());

        toastr()->success('Pump has been created!');
        return redirect()->route('admin.pumps.index');
    }

    public function edit(Pump $pump)
    {
        abort_if(Gate::denies('pump_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.pumps.edit', compact('pump'));
    }

    public function update(UpdatePumpRequest $request, Pump $pump)
    {
        $input = $request->all();
        $request->has('is_fake') ? $input['is_fake'] = 1 : $input['is_fake'] = 0;
        $pump->update($input);

        toastr()->info('Pump has been updated!');
        return redirect()->route('admin.pumps.index');
    }

    public function show(Pump $pump)
    {
        abort_if(Gate::denies('pump_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.pumps.show', compact('pump'));
    }

    public function destroy(Pump $pump)
    {
        abort_if(Gate::denies('pump_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        if(isset($pump->drivewaysheet) && count($pump->drivewaysheet) > 0){
            toastr()->error('Pump has associated data. Please delete it first!');
            return back();
        }
        $pump->forceDelete();

        toastr()->error('Pump has been deleted!');
        return back();
    }

    public function massDestroy(MassDestroyPumpRequest $request)
    {
        $request->validate([
            'ids'   => 'required|array',
        ]);
        foreach($request->ids as $id){
            $pump = Pump::find($id);
            $this->destroy($pump);
        }

        toastr()->error('Pump has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function pumpImport(Request $request)
    {
        if($request->file('upload_file')->extension() == 'xlsx' || $request->file('upload_file')->extension() == 'csv' )
        {
            Excel::import(new PumpImport,$request->file('upload_file'));
            return back()->with("success","File Imported Successfully!");
        }
        return back()->with('error','File type is not correct');
    }
}
