<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Pwa;
use App\Models\Setting;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class SettingController extends Controller
{
    public function generalSetting()
    {
        abort_if(Gate::denies('general_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.settings.general');
    }

    // To store settings key, value.
    public function store(Request $request)
    {
        abort_if(Gate::denies('general_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'name' => 'required|unique:settings',
            'val'  => 'nullable',
        ]);

        $input = $request->all();
        Setting::create($input);
        toastr()->success('Settings has been added');
        return back()->with('added', 'Settings has been added');
    }

    // Verified license checking and general setting update.
    public function general_update(Request $request)
    {
        abort_if(Gate::denies('general_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'logo'          => 'nullable|image|mimes:jpg,jpeg,png,svg',
            'preloader'     => 'nullable|image|mimes:jpg,jpeg,png',
            'companyEmail'       => 'required|email',
            'company_name'        => 'required',
            'website_title'       => 'required',
            'company_address'     => 'required',
            'company_phone'       => 'required|numeric',
            'website_url'         => 'nullable|url',
            'currency_icon' => 'required',
            'currency_code' => 'required',
        ]);

        $input     = $request->except('_token');

        return $this->verifiedupdate($input, $request);
    }



    // To update website general settings.
    public function verifiedupdate($input, $request)
    {

        if (!isset($input['is_preloader'])) {
            $input['is_preloader'] = 0;
        }
        if (!isset($input['is_gotop'])) {
            $input['is_gotop'] = 0;
        }
        if (!isset($input['right_click'])) {
            $input['right_click'] = 0;
        }
        if (!isset($input['inspect'])) {
            $input['inspect'] = 0;
        }
        if (!isset($input['wel_mail'])) {
            $input['wel_mail'] = 0;
        }

        $setting = Setting::all();
        // store website logo
        if ($file = $request->file('logo')) {
            $logo = $setting->where('name', 'logo')->first();
            if (isset($logo) && $logo->val != null) {
                $image_file = @file_get_contents('../public/images/general/' . $logo->val);
                if ($image_file) {
                    unlink('../public/images/general/' . $logo->val);
                }
            }
            $optimizePath = '../public/images/general/';
            if (!file_exists($optimizePath)) {
                mkdir($optimizePath, 666, true);
            }
            $name = time() . '_logo_' . $file->getClientOriginalName();
            $file->move($optimizePath, $name);
            $input['logo'] = $name;
        }
        // store admin logo
        if ($file = $request->file('admin_logo')) {
            $adminlogo = $setting->where('name', 'admin_logo')->first();
            if (isset($adminlogo) && $adminlogo->val != null) {
                $image_file = @file_get_contents('../public/images/general/' . $adminlogo->val);
                if ($image_file) {
                    unlink('../public/images/general/' . $adminlogo->val);
                }
            }
            $optimizePath = '../public/images/general/';
            if (!file_exists($optimizePath)) {
                mkdir($optimizePath, 666, true);
            }
            $name = time() . '_admin_logo_' . $file->getClientOriginalName();
            $file->move($optimizePath, $name);
            $input['admin_logo'] = $name;
        }
        // store small admin logo
        if ($file = $request->file('small_logo')) {
            $smalllogo = $setting->where('name', 'small_logo')->first();
            if (isset($smalllogo) && $smalllogo->val != null) {
                $image_file = @file_get_contents('../public/images/general/' . $smalllogo->val);
                if ($image_file) {
                    unlink('../public/images/general/' . $smalllogo->val);
                }
            }
            $optimizePath = '../public/images/general/';
            if (!file_exists($optimizePath)) {
                mkdir($optimizePath, 666, true);
            }
            $name = time() . '_small_logo_' . $file->getClientOriginalName();
            $file->move($optimizePath, $name);
            $input['small_logo'] = $name;
        }
        // store preloader
        if ($file = $request->file('preloader')) {
            $pre = $setting->where('name', 'preloader')->first();
            if (isset($pre) && $pre->val != null) {
                $image_file = @file_get_contents('../public/images/general/' . $pre->val);
                if ($image_file) {
                    unlink('../public/images/general/' . $pre->val);
                }
            }
            $optimizePath = '../public/images/general/';
            if (!file_exists($optimizePath)) {
                mkdir($optimizePath, 666, true);
            }
            $name = time() . '_preloader_' . $file->getClientOriginalName();
            $file->move($optimizePath, $name);
            $input['preloader'] = $name;
        }
        // store favicon
        if ($file = $request->file('favicon')) {
            $fav = $setting->where('name', 'favicon')->first();
            if (isset($fav) && $fav->val != null) {
                $image_file = @file_get_contents('../public/images/general/' . $fav->val);
                if ($image_file) {
                    unlink('../public/images/general/' . $fav->val);
                }
            }
            $optimizePath = '../public/images/general/';
            if (!file_exists($optimizePath)) {
                mkdir($optimizePath, 666, true);
            }
            $name = time() . '_favicon_' . $file->getClientOriginalName();
            $file->move($optimizePath, $name);
            $input['favicon'] = $name;
        }
        foreach ($input as $key => $val) {
            $data = $setting->where('name', $key)->first();
            if ($data) {
                $data->update(['val' => $val]);
            } else {
                Setting::create(['name' => $key, 'val' => $val]);
            }
        }
        // \Cache::forget('settings');
        toastr()->success('General Settings has been updated');
        return back()->with('updated', 'Settings has been updated');
    }


    public function seoSetting()
    {
        abort_if(Gate::denies('seo_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.settings.seo');
    }

    // To update SEO settings from admin.
    public function seo_update(Request $request)
    {
        abort_if(Gate::denies('seo_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'meta_desc' => 'required',
            'keywords'  => 'required',
        ]);

        $input              = $request->except('_token');
        $input['keywords']  = clean($input['keywords']);
        $input['meta_desc'] = clean($input['meta_desc']);
        $setting            = Setting::all();
        foreach ($input as $key => $val) {
            $data = $setting->where('name', $key)->first();
            if ($data) {
                $data->update(['val' => $val]);
            } else {
                Setting::create(['name' => $key, 'val' => $val]);
            }
        }
        // \Cache::forget('settings');
        toastr()->success('SEO Settings has been updated');
        return back()->with('updated', 'SEO setting has been updated');
    }


    public function pwaSetting()
    {
        abort_if(Gate::denies('pwa_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $pwa = Pwa::pluck('val', 'name');
        return view('admin.settings.pwa',compact('pwa'));
    }

    // To update PWA settings
    public function updatesetting(Request $request)
    {
        abort_if(Gate::denies('pwa_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if (env('DEMO_LOCK') == 1) {
            // flash('This action is disabled in demo !')->error();
            return back();
        }
        $input           = $request->except('_token');
        $input['is_pwa'] = isset($request->is_pwa) ? 1 : 0;
        $pwasetting      = Pwa::all();
        foreach ($input as $key => $val) {
            $data = $pwasetting->where('name', $key)->first();
            if ($data) {
                $data->update(['val' => $val]);
            } else {
                Pwa::create(['name' => $key, 'val' => $val]);
            }
        }
        // \Cache::forget('pwa');
        toastr()->info('App Setting Updated');
        return back();
    }



    // To update PWA icons.
    public function updateicons(Request $request)
    {
        if (env('DEMO_LOCK') == 1) {
            // flash('This action is disabled in demo !')->error();
            return back();
        }
        $pwasetting = Pwa::all();
        $pwa        = $pwasetting->pluck('val', 'name');
        $icons      = \Config::get('laravelpwa.manifest.icons');
        $input      = $request->except('_token');
        if ($file = $request->file('icon_48')) {
            $input['icon_48'] = 'icon-48x48-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['icon_48']) && file_exists('../public/images/icons/' . $pwa['icon_48'])) {
                @unlink('../public/images/icons/' . $pwa['icon_48']);
            }
            $file->move('images/icons', $input['icon_48']);
        }

        if ($file = $request->file('icon_72')) {
            $input['icon_72'] = 'icon-72x72-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['icon_72']) && file_exists('../public/images/icons/' . $pwa['icon_72'])) {
                @unlink('../public/images/icons/' . $pwa['icon_72']);
            }
            $file->move('images/icons', $input['icon_72']);
        }

        if ($file = $request->file('icon_96')) {
            $input['icon_96'] = 'icon-96x96-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['icon_96']) && file_exists('../public/images/icons/' . $pwa['icon_96'])) {
                @@unlink('../public/images/icons/' . $pwa['icon_96']);
            }
            $file->move('images/icons', $input['icon_96']);
        }

        if ($file = $request->file('icon_128')) {
            $input['icon_128'] = 'icon-128x128-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['icon_128']) && file_exists('../public/images/icons/' . $pwa['icon_128'])) {
                @@unlink('../public/images/icons/' . $pwa['icon_128']);
            }
            $file->move('images/icons', $input['icon_128']);
        }

        if ($file = $request->file('icon_144')) {
            $input['icon_144'] = 'icon-144x144-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['icon_144']) && file_exists('../public/images/icons/' . $pwa['icon_144'])) {
                @unlink('../public/images/icons/' . $pwa['icon_144']);
            }
            $file->move('images/icons', $input['icon_144']);
        }

        if ($file = $request->file('icon_192')) {
            $input['icon_192'] = 'icon-192x192-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['icon_192']) && file_exists('../public/images/icons/' . $pwa['icon_192'])) {
                @unlink('../public/images/icons/' . $pwa['icon_192']);
            }
            $file->move('images/icons', $input['icon_192']);
        }

        if ($file = $request->file('icon_256')) {
            $input['icon_256'] = 'icon-256x256-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['icon_256']) && file_exists('../public/images/icons/' . $pwa['icon_256'])) {
                @unlink('../public/images/icons/' . $pwa['icon_256']);
            }
            $file->move('images/icons', $input['icon_256']);
        }

        if ($file = $request->file('icon_512')) {
            $input['icon_512'] = 'icon-512x512-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['icon_512']) && file_exists('../public/images/icons/' . $pwa['icon_512'])) {
                @unlink('../public/images/icons/' . $pwa['icon_512']);
            }
            $file->move('images/icons', $input['icon_512']);

        }

        /** Splash Screens */

        /** 640 x 1136 */

        if ($file = $request->file('splash_640')) {
            $input['splash_640'] = 'splash-640x1136-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_640']) && file_exists('../public/images/icons/' . $pwa['splash_640'])) {
                @unlink('../public/images/icons/' . $pwa['splash_640']);
            }
            $file->move('images/icons', $input['splash_640']);
        }

        /** 750x1334 */

        if ($file = $request->file('splash_750')) {
            $input['splash_750'] = 'splash-750x1334-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_750']) && file_exists('../public/images/icons/' . $pwa['splash_750'])) {
                @unlink('../public/images/icons/' . $pwa['splash_750']);
            }
            $file->move('images/icons', $input['splash_750']);
        }

        /** 828x1792 */

        if ($file = $request->file('splash_828')) {
            $input['splash_828'] = 'splash-828x1334-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_828']) && file_exists('../public/images/icons/' . $pwa['splash_828'])) {
                @unlink('../public/images/icons/' . $pwa['splash_828']);
            }
            $file->move('images/icons', $input['splash_828']);
        }

        /** 1125x2436 */

        if ($file = $request->file('splash_1125')) {
            $input['splash_1125'] = 'splash-1125x2436-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_1125']) && file_exists('../public/images/icons/' . $pwa['splash_1125'])) {
                @unlink('../public/images/icons/' . $pwa['splash_1125']);
            }
            $file->move('images/icons', $input['splash_1125']);
        }

        /** 1242x2208 */

        if ($file = $request->file('splash_1242')) {
            $input['splash_1242'] = 'splash-1242x2208-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_1242']) && file_exists('../public/images/icons/' . $pwa['splash_1242'])) {
                @unlink('../public/images/icons/' . $pwa['splash_1242']);
            }
            $file->move('images/icons', $input['splash_1242']);
        }

        /** 1536x2048 */

        if ($file = $request->file('splash_1536')) {
            $input['splash_1536'] = 'splash-1536x2048-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_1536']) && file_exists('../public/images/icons/' . $pwa['splash_1536'])) {
                @unlink('../public/images/icons/' . $pwa['splash_1536']);
            }
            $file->move('images/icons', $input['splash_1536']);
        }

        /** 1668x2224 */

        if ($file = $request->file('splash_1668')) {
            $input['splash_1668'] = 'splash-1668x2224-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_1668']) && file_exists('../public/images/icons/' . $pwa['splash_1668'])) {
                @unlink('../public/images/icons/' . $pwa['splash_1668']);
            }
            $file->move('images/icons', $input['splash_1668']);
        }

        /** 1668x2388 */

        if ($file = $request->file('splash_2388')) {
            $input['splash_1668'] = 'splash-1668x2388-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_2388']) && file_exists('../public/images/icons/' . $pwa['splash_2388'])) {
                @unlink('../public/images/icons/' . $pwa['splash_2388']);
            }
            $file->move('images/icons', $input['splash_1668']);
        }

        /** 2048x2732 */

        if ($file = $request->file('splash_2048')) {
            $input['splash_2048'] = 'splash-2048x2732-' . time() . '.' . $file->getClientOriginalExtension();
            if (isset($pwa['splash_2048']) && file_exists('../public/images/icons/' . $pwa['splash_2048'])) {
                @unlink('../public/images/icons/' . $pwa['splash_2048']);
            }
            $file->move('images/icons', $input['splash_2048']);
        }
        foreach ($input as $key => $val) {
            $data = $pwasetting->where('name', $key)->first();
            if ($data) {
                $data->update(['val' => $val]);
            } else {
                Pwa::create(['name' => $key, 'val' => $val]);
            }
        }
        // \Cache::forget('pwa');
        toastr()->success('PWA settings are updated successfully');
        return back();
    }



    public function mailSetting()
    {
        abort_if(Gate::denies('mail_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.settings.mail');
    }



    public function backupRestore()
    {
        abort_if(Gate::denies('backup_restore_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.settings.backupRestore');
    }
}
