<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\ShiftNo;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Gate;

class ShiftNoController extends Controller
{
     public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('shift_no_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $shift_list = ShiftNo::where('branch_id',$this->branch_id)->get();
        return view('admin.shiftNo.index',compact('shift_list'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('shift_no_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'title' => 'required|string|max:40|unique:shift_nos',
            // 'remarks' => 'nullable|max:80',
            'status' => 'nullable',
        ]);
        $input = $request->all();
        $input['status'] = isset($input['status']) ? $input['status'] : '0';
        $input['branch_id'] = $this->branch_id;
        ShiftNo::create($input);
        toastr()->success('Shift is created successfully!');
        return redirect()->route('admin.shift-nos.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($shift)
    {
        abort_if(Gate::denies('shift_no_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $shift = ShiftNo::find($shift);
        $shift_list = ShiftNo::where('branch_id',$this->branch_id)->get();
        return view('admin.shiftNo.index',compact('shift_list','shift'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request,$shift)
    {
        abort_if(Gate::denies('shift_no_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $shift = ShiftNo::find($shift);
        $request->validate([
            'title' => 'required|string|max:40',
            'status' => 'nullable',
        ]);
        $input = $request->all();
        $input['status'] = isset($input['status']) ? $input['status'] : '0';
        $input['branch_id'] = $this->branch_id;
        $shift->update($input);
        toastr()->info('Shift has been updated successfully!');
        return redirect()->route('admin.shift-nos.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($shift)
    {
        abort_if(Gate::denies('shift_no_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $shift = ShiftNo::find($shift);
        if((isset($shift->speedPoint) && count($shift->speedPoint) > 0) || (isset($shift->account) && count($shift->account) > 0) ){
            toastr()->error('It has associated data. Please delete that first!');
            return back();
        }
        $shift->forceDelete();
        toastr()->error('Shift has been deleted!');
        return back();
    }

    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('shift_no_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
            'ids.*' => 'exists:shift_nos,id',
        ]);

        foreach($request->ids as $id){
            $this->destroy($id);
        }
        // toastr()->error('Shift has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
