<?php

namespace App\Http\Requests;

use App\Models\Account;
use Gate;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Response;

class StoreAccountRequest extends FormRequest
{
    public function authorize()
    {
        return Gate::allows('cash_credit_account_create');
    }

    public function rules()
    {
        return [
            'date' => [
                'required',
                'date_format:' . config('panel.date_format'),
            ],
            'shift.*' => [
                'nullable',
                'integer',
            ],
            'attachment.*' => 'nullable|image|mimes:jpg,jpeg,png,svg',
            'invoice_no.*' => [
                'required',
                'string',
                'unique:accounts,invoice_no',
            ],
            'amount.*' => [
                'required',
                'numeric',
            ],
            'company.*' => [
                'required',
                'integer',
            ],
            'order_no.*' => [
                'nullable',
                'max:30',
            ],
            'veh_reg_no.*' => [
                'nullable',
                'max:30',
            ],
            'fleet_no.*' => [
                'nullable',
                'max:30',
            ],
            'd_name.*' => [
                'nullable',
                'max:40',
            ],
        ];
    }

    public function messages()
    {
        return [
            'invoice_no.*.required' => 'The invoice no field is required.',
            'attachment.*.mimes' => 'The attachment must be jpg, jpeg, png, svg.',
            'invoice_no.*.unique' => 'The invoice no is already taken.',
            'amount.*.required' => 'The amount field is required.',
            'company.*.required' => 'The company name field is required.',
            'amount.*.numeric' => 'The amount must be number.',
        ];
    }
}
