<?php

namespace App\Http\Requests;

use App\Models\CashPurchase;
use Gate;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Response;

class StoreCashPurchaseRequest extends FormRequest
{
    public function authorize()
    {
        return Gate::allows('cash_purchase_create');
    }

    public function rules()
    {
        return [
            'date' => [
                'required',
            ],
            'invoice_no.*' => [
                'max:20',
                'required',
                'unique:cash_purchases,invoice_no',
            ],
            'suplier.*' => [
                'nullable',
                'integer',
            ],
            'bank_account.*' => [
                'nullable',
                'integer',
            ],
            'financial_category.*' => [
                'nullable',
                'integer',
            ],
            'cash_credit.*' => [
                'required',
            ],
            'reference.*' => [
                'nullable',
            ],
            'vat.*' => [
                'nullable',
            ],

            'attachment.*' => 'nullable|image|mimes:jpg,jpeg,png,svg',

            'total_amount.*' => [
                'required',
            ],
        ];
    }

    public function messages()
    {
        return [
            'date.*.required' => 'The date field is required.',
            'invoice_no.*.required' => 'The invoice no. field is required.',
            'invoice_no.*.unique' => 'The invoice no. has already taken.',
            'suplier.*.required' => 'The suplier field is required.',
            'cash_credit.*.required' => 'The cash credit field is required.',
            'attachment.*.mimes' => 'The attachment must be jpg, jpeg, png, svg.',
            'total_amount.*.required' => 'The total amount field is required.',
            'total_amount.*.numeric' => 'The amount field must be a number.',
        ];
    }
}
