<?php

namespace App\Http\Requests;

use App\Models\PaymentAdvice;
use Gate;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Response;

class StorePaymentAdviceRequest extends FormRequest
{
    public function authorize()
    {
        return Gate::allows('payment_advice_create');
    }

    public function rules()
    {
        return [
            'date' => [
                'required',
            ],
            'invoice_no.*' => [
                'required',
                'string',
                'unique:payment_advices,invoice'
            ],
            'd_note_no.*' => [
                'nullable',
            ],
            'product.*' => [
                'required',
            ],
            'r_quantity.*' => [
                'nullable',
                'integer',
                'min:-2147483648',
                'max:2147483647',
            ],
        ];
    }

    public function messages()
    {
        return [
            'date.required' => 'The date field is required.',
            'invoice_no.*.required' => 'The invoice no field is required.',
            'invoice_no.*.unique' => 'The invoice no has already taken.',
            'product.*.required' => 'The product field is required.',
        ];
    }
}
