@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.account.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        {{-- <li class="breadcrumb-item"><a href="{{route('admin.speed-points.index')}}">{{trans('cruds.speedPoint.title') }}</a>
                        </li> --}}
                        <li class="breadcrumb-item active">{{trans('cruds.account.title')}}</li>
                    </ul>
                </div>
                @can('cash_credit_account_create')
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.accounts.create') }}" class="btn add-btn"> <i
                            class="fa fa-plus"></i>{{ trans('cruds.account.title_singular') }}</a>
                </div>
                @endcan
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.account.title_singular') }} {{ trans('global.list') }}
            </div>

            <div class="card-body">
                <div class="row filter-row">
                  <div class="col-sm-3 col-md-3">
                    <div class="form-group form-focus">
                      <div class="cal-icon">
                        <input class="form-control floating date" name="min_date" type="text">
                      </div>
                      <label class="focus-label">From</label>
                    </div>
                  </div>
                  <div class="col-sm-3 col-md-3">
                    <div class="form-group form-focus">
                      <div class="cal-icon">
                        <input class="form-control floating date" name="max_date" type="text">
                      </div>
                      <label class="focus-label">To</label>
                    </div>
                  </div>
                  <div class="col-sm-2 col-md-2">
                    <a href="#" class="btn btn-success search-btn"> Search </a>
                    <a class="btn btn-info" href="{{ route('admin.accounts.index') }}">Reset</a>
                  </div>
                </div>
                <table class=" table table-bordered table-hover ajaxTable datatable datatable-Account">
                    <thead>
                        <tr>
                            <th width="10">

                            </th>
                            <th>
                                {{ trans('cruds.account.fields.id') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.day') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.shift_no') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.invoice_no') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.company_name') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.amount') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.order_no') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.veh_reg_no') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.fleet_no') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.d_name') }}
                            </th>
                            <th>
                                &nbsp;
                            </th>
                        </tr>
                    </thead>
                </table>
            </div>
        </div>
    </div>
</div>



@endsection
@section('scripts')
@parent
<script>
    $(function () {
        let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
        @can('cash_credit_account_delete')
        let deleteButtonTrans = '{{ trans('global.datatables.delete') }}';
        let deleteButton = {
            text: deleteButtonTrans,
            url: "{{ route('admin.accounts.massDestroy') }}",
            className: 'bg-inverse-danger',
            action: function (e, dt, node, config) {
            var ids = $.map(dt.rows({ selected: true }).data(), function (entry) {
                return entry.id
            });

            if (ids.length === 0) {
                alert('{{ trans('global.datatables.zero_selected') }}')

                return
            }

            if (confirm('{{ trans('global.areYouSure') }}')) {
                $.ajax({
                headers: {'x-csrf-token': _token},
                method: 'POST',
                url: config.url,
                data: { ids: ids, _method: 'DELETE' }})
                .done(function () { location.reload() })
            }
            }
        }
        dtButtons.push(deleteButton)
        @endcan

        let dtOverrideGlobals = {
            buttons: dtButtons,
            processing: true,
            serverSide: true,
            retrieve: true,
            aaSorting: [],
            ajax: {
              url: "{{ route('admin.accounts.index') }}",
                  data: function(d) {
                      d.min = $('input[name=min_date]').val();
                      d.max = $('input[name=max_date]').val();
                  }
              },
            columns: [{
                    data: 'placeholder',
                    name: 'placeholder'
                },
                {data: 'DT_RowIndex', name: 'DT_RowIndex',searchable:false,orderable:false},
                {
                    data: 'date',
                    name: 'date'
                },
                {
                    data: 'shift_no',
                    name: 'shift_no'
                },
                {
                    data: 'invoice_no',
                    name: 'invoice_no'
                },
                {
                    data: 'company_name',
                    name: 'company_name'
                },
                {
                    data: 'amount',
                    name: 'amount'
                },
                {
                    data: 'order_no',
                    name: 'order_no'
                },
                {
                    data: 'veh_reg_no',
                    name: 'veh_reg_no'
                },
                {
                    data: 'fleet_no',
                    name: 'fleet_no'
                },
                {
                    data: 'd_name',
                    name: 'd_name'
                },
                {
                    data: 'actions',
                    name: '{{ trans('global.actions ') }}'
                }
            ],
            orderCellsTop: true,
            order: [
                [0, 'desc']
            ],
            pageLength: 100,
        };
        let table = $('.datatable-Account').DataTable(dtOverrideGlobals);
        $('a[data-toggle="tab"]').on('shown.bs.tab click', function (e) {
            $($.fn.dataTable.tables(true)).DataTable()
                .columns.adjust();
        });

      // Event listener to the two range filtering inputs to redraw on input
      $('.search-btn').on("click", function(e) {
          e.preventDefault();
          $('input[name=min_date]').attr('required',true);
          $('input[name=max_date]').attr('required',true);
          if($('input[name=min_date]').val() != '' && $('input[name=max_date]').val() != ''){
              table.draw();
          }
          else{
              toastr.error('Min & Max date both are required.');
          }
      });
    });

</script>
@endsection
