@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.bankAccount.title')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.bank-accounts.index')}}">{{trans('cruds.bankAccount.title')}}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.bank-accounts.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i> {{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.bankAccount.title') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.bank-accounts.store") }}" enctype="multipart/form-data">
                    @csrf
                    <div class="row">
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="bank_name">{{ trans('cruds.bankAccount.fields.bank') }}</label>
                                <input class="form-control {{ $errors->has('bank_name') ? 'is-invalid' : '' }}" type="text" name="bank_name" id="bank_name" value="{{ old('bank_name', '') }}" required>
                                @if($errors->has('bank_name'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('bank_name') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.bankAccount.fields.bank_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="account_no">{{ trans('cruds.bankAccount.fields.account_no') }}</label>
                                <input class="form-control {{ $errors->has('account_no') ? 'is-invalid' : '' }}" type="text" name="account_no" id="account_no" value="{{ old('account_no', '') }}">
                                @if($errors->has('account_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('account_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.bankAccount.fields.account_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="balance">{{ trans('cruds.bankAccount.fields.balance')}}</label>
                                <input class="form-control {{ $errors->has('balance') ? 'is-invalid' : '' }}" type="number" step="any" name="balance" id="balance" value="{{ old('balance', '') }}" >
                                @if($errors->has('balance'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('balance') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.bankAccount.fields.balance_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="contact_person">{{ trans('cruds.bankAccount.fields.contact_person') }}</label>
                                <input class="form-control {{ $errors->has('contact_person') ? 'is-invalid' : '' }}" type="text" name="contact_person" id="contact_person" value="{{ old('contact_person', '') }}" >
                                @if($errors->has('contact_person'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('contact_person') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.bankAccount.fields.contact_person_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="phone">{{ trans('cruds.bankAccount.fields.phone') }}</label>
                                <input class="form-control {{ $errors->has('phone') ? 'is-invalid' : '' }}" type="text" maxlength="10" name="phone" id="phone" value="{{ old('phone', '') }}" >
                                @if($errors->has('phone'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('phone') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.bankAccount.fields.phone_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label for="remarks">{{ trans('cruds.siteReg.type.remarks') }}</label>
                                <input class="form-control {{ $errors->has('remarks') ? 'is-invalid' : '' }}" type="text" name="remarks" id="fuel" value="{{ old('remarks', '') }}">
                                @if($errors->has('remarks'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('remarks') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.type.remarks_helper') }}</span>
                            </div>

                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">
                                <button class="btn btn-info" type="reset">
                                    {{ trans('global.reset') }}
                                </button>
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>



@endsection
