@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.cashierSale.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item"><a
                                href="{{route('admin.cashier-sales.index')}}">{{trans('cruds.cashierSale.title') }}</a>
                        </li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ url('admin/cashier-sales?date='.$date)  }}" class="btn add-btn"> <i
                            class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            @include('partials.drivewayPartial') 
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.cashierSale.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.cashier-sales.store") }}" enctype="multipart/form-data" id="cashier_form">
                    @csrf
                   <div class="row">
                       <div class="col-lg-4">
                           <div class="form-group">
                               <label for="date">{{ trans('cruds.cashierSale.fields.date') }}</label>
                               <input type="text" name="date" id="date" class="form-control date {{$errors->has('date')? 'is-invalid':''}}" value={{isset($date) && $date != null ? date('d/m/Y',strtotime($date)) : null}} {{isset($date) && $date != null ? 'readonly' : ''}}  required>
                               @if ($errors->first('date'))
                                   <div class="invalid-feedback">
                                       {{$errors->first('date')}}
                                   </div>
                               @endif
                           </div>
                       </div>
                   </div>
                   <div class="row">
                       <div class="col-lg-12">
                           <table class="table table-bordered" id="field_container">
                               <tr>
                                   <th>
                                       {{ trans('cruds.cashierSale.fields.sub_category') }}
                                   </th>
                                    <th>
                                       {{ trans('cruds.cashierSale.fields.cashier') }}
                                   </th> 
                                   <th>
                                       {{ trans('cruds.cashierSale.fields.amount') }}
                                   </th>
                                   <th>
                                       {{ trans('cruds.cashierSale.fields.detail') }}
                                   </th>
                                   <th></th>
                               </tr>
                               <tr id="copy_content">
                                <td>
                                    <div class="form-group small">
                                        <select name="sub_category[0]" class="form-control {{$errors->has('sub_category.*') ? 'is-invalid' : ''}}" id="sub_category" required>
                                            @foreach ($subCategory as $key => $value )
                                                <option value="{{$key}}">{{$value}}</option>
                                            @endforeach
                                        </select>
                                        @if($errors->first('sub_category.*'))
                                            <div class="invalid-feedback">
                                                {{ $errors->first('sub_category.*') }}
                                            </div>
                                        @endif
                                    </div>
                                </td>
                                <td>
                                    <div class="form-group small">
                                        <select name="cashier_id[0]" class="form-control {{$errors->has('cashier_id.*') ? 'is-invalid' : ''}}" id="cashier_id" required>
                                            @foreach ($cashiers as $key => $value )
                                                <option value="{{$key}}">{{$value}}</option>
                                            @endforeach
                                        </select>
                                        @if($errors->first('cashier_id.*'))
                                            <div class="invalid-feedback">
                                                {{ $errors->first('cashier_id.*') }}
                                            </div>
                                        @endif
                                    </div>
                                </td>
                                <td>
                                    <div class="form-group small">
                                        <input type="number" min="1" step="any" class="form-control {{ $errors->has('amount.*') ? 'is-invalid' : ''}}" id="amount" name="amount[0]" value="{{ old('amount[0]') }}" required>
                                        @if($errors->first('amount.*'))
                                            <div class="invalid-feedback">
                                                {{ $errors->first('amount.*') }}
                                            </div>
                                        @endif
                                        <span class="help-block">{{ trans('cruds.cashierSale.fields.amount_helper') }}</span>
                                    </div>
                                </td>
                                <td>
                                    <div class="form-group small">
                                        <input type="text" class="form-control {{ $errors->has('detail.*') ? 'is-invalid' : ''}}" id="detail" name="detail[0]" value="{{ old('detail[0]') }}">
                                        @if($errors->first('detail.*'))
                                            <div class="invalid-feedback">
                                                {{ $errors->first('detail.*') }}
                                            </div>
                                        @endif
                                        <span class="help-block">{{ trans('cruds.cashierSale.fields.detail_helper') }}</span>
                                    </div>
                                </td>
                                <td><a href="#" class="btn btn-xs btn-danger d-none" id="remove"><i class="fa fa-trash"></i></a></td>
                            </tr>
                           </table>
                            <div class="row my-3">
                                <div class="col-lg-12 text-center">
                                    <button class="btn btn-block btn-light" id="add_row">Add Row</button>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <button class="btn btn-info" type="reset">
                                            {{ trans('global.reset') }}
                                        </button>
                                        <button class="btn btn-primary" id="btn_submit" type="submit">
                                            {{ trans('global.save') }}
                                        </button>
                                    </div>
                                </div>
                            </div>
                       </div>
                   </div>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(document).ready(function(){
            var max = 15;
           var x=0;

            $('#add_row').click(function (e) {
                e.preventDefault();
                if(x < max)
                {
                    x++;
                    var clone_ele = $('#copy_content').clone();
                    clone_ele.find('#remove').removeClass('d-none');
                    clone_ele.find(':input').each(function(){
                        this.value = '';
                        this.id = this.id + '-' + x;
                        this.name = this.name.replace(/\[[0-9]\]+/, '[' + x + ']');
                    });
                    clone_ele.appendTo('#field_container');
                }
            });


            $('#field_container').on('click','#remove',function (e) {
                e.preventDefault();
                $(this).closest('tr').remove();
            });
            var i = 0;
            $('#cashier_form').on("submit",function (e) {
                e.preventDefault();
                $("#btn_submit").prop('disabled', true);
               $.ajax({
                   type: this.method,
                   url: this.action,
                   data:new FormData(this),
                   dataType:'JSON',
                   contentType: false,
                   cache: false,
                   processData: false,
                   beforeSend: function(response){
                   },
                   success: function (response) {
                    if (response.success) {
                        toastr.success(response.message);
                        document.getElementById('cashier_form').reset();
                        setTimeout(function(){
                            window.location = response.url;
                        },1000);
                    }
                    $("#btn_submit").prop('disabled', false);
                   },
                   error: function(response){
                        $.each(response.responseJSON.errors, function (index, value) {
                          toastr.error(value);
                          $("#btn_submit").prop('disabled', false);
                        });
                    }
               });

            });
        });
    </script>
@endsection

