@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.currencyInfo.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        @if (isset($currency_info))
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item"><a
                                href="{{route('admin.currency-infos.index')}}">{{trans('cruds.currencyInfo.title')}}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                        @else
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item active">{{trans('cruds.currencyInfo.title')}}</li>
                        @endif
                    </ul>
                </div>
                @if(isset($currency_info))
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.currency-infos.index') }}" class="btn add-btn"> <i
                            class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
                @else
                {{-- <div class="col-auto float-right ml-auto">
                    <a href="" class="btn add-btn"> <i class="fa fa-plus"></i>{{ trans('global.add')}}
                        {{trans('cruds.currencyInfo.title_singular')}}</a>
                </div> --}}
                @endif
            </div>
        </div>
        @can(['currency_create','currency_edit'])
            <div class="card">
                <div class="card-header">
                    @if (isset($currency_info))
                    {{ trans('global.edit') }} {{ trans('cruds.currencyInfo.title_singular') }}
                    @else
                    {{ trans('global.add') }} {{ trans('cruds.currencyInfo.title_singular') }}
                    @endif
                </div>
                <div class="card-body">
                    @if (isset($currency_info))
                    <form action="{{route('admin.currency-infos.update',[$currency_info->id])}}" method="POST" enctype="multipart/form-data">
                    @method('PUT')
                    @else
                    <form action="{{route('admin.currency-infos.store')}}" method="post" enctype="multipart/form-data">
                    @endif
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required"
                                    for="date">{{ trans('cruds.currencyInfo.fields.date') }}</label>
                                <input class="form-control floating datetimepicker {{ $errors->has('date') ? 'is-invalid' : '' }}"
                                    type="text" name="date" id="date"
                                    value="{{ old('date', isset($currency_info)?date('d/m/Y',strtotime($currency_info->date)):'') }}" required>
                                @if($errors->has('date'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('date') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.currencyInfo.fields.date_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required"
                                    for="currency">{{ trans('cruds.currencyInfo.fields.currency') }}</label>
                                    <select name="currency" id="currency" class="form-control select2 {{ $errors->has('currency') ? 'is-invalid' : '' }}" required>
                                        @foreach ($currency as $key => $val)
                                            <option value="{{$key}}" {{isset($currency_info) && $currency_info->currency == $key ? 'selected' :''}}>{{$val}}</option>
                                        @endforeach
                                    </select>
                                @if($errors->has('currency'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('currency') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.currencyInfo.fields.currency_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required"
                                    for="rate">{{ trans('cruds.currencyInfo.fields.rate') }}</label>
                                <input class="form-control {{ $errors->has('rate') ? 'is-invalid' : '' }}"
                                    type="number" step="any" name="rate" id="rate"
                                    value="{{ old('rate', isset($currency_info)?$currency_info->rate:'') }}" required>
                                @if($errors->has('rate'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('rate') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.currencyInfo.fields.rate_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            @if (isset($currency_info))
                            <button class="btn btn-primary" type="submit">{{ trans('global.update') }}</button>
                            @else
                            <button class="btn btn-info" type="reset">{{ trans('global.reset') }}</button>
                            <button class="btn btn-primary" type="submit">{{ trans('global.add') }}</button>
                            @endif
                        </div>
                    </div>
                </div>
                </form>
            </div>
        @endcan

        <div class="card">
            <div class="card-header">
                {{ trans('global.list') }} {{ trans('cruds.currencyInfo.title_singular') }}
            </div>
            <div class="card-body">
                <table class="table table-bordered datatable-currency">
                    <thead>
                        <tr>
                            <th style="width: 10px;"></th>
                            <th>
                                {{__('ID')}}
                            </th>
                            <th>
                                {{ trans('cruds.currencyInfo.fields.date') }}
                            </th>
                            <th>
                                {{ trans('cruds.currencyInfo.fields.currency') }}
                            </th>
                            <th>
                                {{ trans('cruds.currencyInfo.fields.currency_sym') }}
                            </th>
                            <th>
                                {{ trans('cruds.currencyInfo.fields.rate') }}
                            </th>
                            <th></th>
                        </tr>
                    </thead>
                    <tbody>
                        @if (count($currency_info_list) == 0)
                        {{-- <tr>
                            <td colspan="4" style="text-align: center;">
                                <span>Records not found</span>
                            </td>
                        </tr> --}}
                        @else
                        @php
                            $i = 1;
                        @endphp
                        @foreach ($currency_info_list as $sl)
                        <tr data-entry-id="{{$sl->id}}">
                            <td></td>
                            <td>
                                {{$i}}
                            </td>
                            <td>
                                {{date('d/m/Y',strtotime($sl->date))}}
                            </td>
                            <td>
                                {{$sl->all_currency->code}}
                            </td>
                            <td>
                                {{$sl->all_currency->symbol}}
                            </td>
                            <td>
                                {{number_format($sl->rate,2)}}
                            </td>
                            <td>
                                <div class="button-list">
                                    @can('currency_edit')
                                        <a href="{{route('admin.currency-infos.edit', $sl->id)}}" class="btn btn-xs btn-info"><i
                                                class="la la-edit"></i></a>
                                    @endcan
                                    @can('currency_delete')
                                        <button type="button" class="btn btn-xs btn-danger" data-toggle="modal"
                                            data-target="#deleteModal{{$sl->id}}"><i class="la la-trash"></i></button>
                                    @endcan
                                    <!-- Modal -->
                                    <div id="deleteModal{{$sl->id}}" class="delete-modal modal fade" role="dialog">
                                        <div class="modal-dialog modal-sm">
                                            <div class="modal-content">
                                                <div class="modal-header">
                                                    <button type="button" class="close"
                                                        data-dismiss="modal">&times;</button>
                                                    <div class="delete-icon"></div>
                                                </div>
                                                <div class="modal-body text-center">
                                                    <h4 class="modal-heading">Are You Sure ?</h4>
                                                    <p>Do you really want to delete these records?<br> This process cannot
                                                        be
                                                        undone.</p>
                                                </div>
                                                <div class="modal-footer">
                                                    {!! Form::open(['method' => 'DELETE', 'route' =>
                                                    ['admin.currency-infos.destroy',$sl->id]]) !!}
                                                    <button type="reset" class="btn btn-dark"
                                                        data-dismiss="modal">No</button>
                                                    <button type="submit" class="btn btn-danger">Yes</button>
                                                    {!! Form::close() !!}
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </td>
                            @php
                                $i++;
                            @endphp
                        </tr>
                        @endforeach
                        @endif
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(function () {
            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('currency_delete')
            let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
            let deleteButton = {
                text: deleteButtonTrans,
                url: "{{ route('admin.currency-infos.massDestroy') }}",
                className: 'bg-inverse-danger',
                action: function (e, dt, node, config) {
                var ids = $.map(dt.rows({ selected: true }).nodes(), function (entry) {
                    return $(entry).data('entry-id')
                });

                if (ids.length === 0) {
                    alert('{{ trans('global.datatables.zero_selected') }}')

                    return
                }

                if (confirm('{{ trans('global.areYouSure') }}')) {
                    $.ajax({
                    headers: {'x-csrf-token': _token},
                    method: 'POST',
                    url: config.url,
                    data: { ids: ids, _method: 'DELETE' }})
                    .done(function () { location.reload() })
                }
                }
            }
            dtButtons.push(deleteButton)
            @endcan

            $.extend(true, $.fn.dataTable.defaults, {
                orderCellsTop: true,
                order: [[ 1, 'asc' ]],
                pageLength: 100,
            });
            let table = $('.datatable-currency').DataTable({ buttons: dtButtons })
            $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
                $($.fn.dataTable.tables(true)).DataTable()
                    .columns.adjust();
            });
            $('div#sidebar').on('transitionend', function(e) {
                $($.fn.dataTable.tables(true)).DataTable().columns.adjust();
            })

        })
    </script>
@endsection
