@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
  <div class="content container-fluid">
    <div class="page-header">
      <div class="row align-items-center">
        <div class="col">
          <h3 class="page-title">{{ trans('cruds.deposit.title_singular') }}</h3>
          <ul class="breadcrumb">
            <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
            <li class="breadcrumb-item active">{{ trans('cruds.deposit.title') }}</li>
          </ul>
        </div>
        @can('deposit_create')
            <div class="col-auto float-right ml-auto">
                <a href="{{ $date != null ? url('admin/deposits/create?date='.$date) : url('admin/deposits/create')}}" class="btn add-btn"> <i class="fa fa-plus"></i>{{ trans('global.add') }} {{ trans('cruds.deposit.title_singular') }}</a>
            </div>
        @endcan
      </div>
    </div>
    <div class="card">
      @if($date != null)
      @include('partials.drivewayPartial')
      @endif
      <div class="card-header">
        {{ trans('cruds.deposit.title') }} {{ trans('global.list') }}
      </div>
      <div class="card-body">
        @if($date == null)
        <div class="row filter-row">
          <div class="col-sm-3 col-md-3">
            <div class="form-group form-focus">
              <div class="cal-icon">
                <input class="form-control floating date" name="min_date" type="text">
              </div>
              <label class="focus-label">From</label>
            </div>
          </div>
          <div class="col-sm-3 col-md-3">
            <div class="form-group form-focus">
              <div class="cal-icon">
                <input class="form-control floating date" name="max_date" type="text">
              </div>
              <label class="focus-label">To</label>
            </div>
          </div>
          <div class="col-sm-2 col-md-2">
            <a href="#" class="btn btn-success search-btn"> Search </a>
            <a class="btn btn-info" href="{{ route('admin.deposits.index') }}">Reset</a>
          </div>
        </div>
        @endif
        <div class="table-responsive">
          <table class=" table table-bordered table-hover datatable datatable-deposit">
            <thead>
              <tr>
                <th width="10">
                </th>
                <th>{{__('ID')}}</th>
                <th>
                  {{ trans('cruds.deposit.fields.date') }}
                </th>
                <th>
                  {{ trans('cruds.deposit.fields.sub_category') }}
                </th>
                <th>
                  {{ trans('cruds.deposit.fields.amount') }}
                </th>
                <th>
                  {{ trans('cruds.deposit.fields.bank_account') }}
                </th>
                <th>
                  {{ trans('cruds.deposit.fields.detail') }}
                </th>
                @can('deposit_bank_statement')
                    <th>
                    {{ trans('cruds.deposit.fields.bank_statements') }}
                    </th>
                @endcan
                <th>
                  &nbsp;
                </th>
              </tr>
            </thead>
            <tbody>
            </tbody>
          </table>
        </div>
      </div>
    </div>
  </div>
</div>
@endsection
@section('scripts')
@parent
<script>
$(function () {
  "use strict";
  var times = {!!json_encode($bankdata)!!};
  let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
        @can('deposit_delete')
        let deleteButtonTrans = '{{ trans('global.datatables.delete') }}';
        let deleteButton = {
            text: deleteButtonTrans,
            url: "{{ route('admin.deposits.massDestroy') }}",
            className: 'bg-inverse-danger',
            action: function (e, dt, node, config) {
            var ids = $.map(dt.rows({ selected: true }).data(), function (entry) {
                return entry.id
            });

            if (ids.length === 0) {
                alert('{{ trans('global.datatables.zero_selected') }}')

                return
            }

            if (confirm('{{ trans('global.areYouSure') }}')) {
                $.ajax({
                headers: {'x-csrf-token': _token},
                method: 'POST',
                url: config.url,
                data: { ids: ids, _method: 'DELETE' }})
                .done(function () { location.reload() })
            }
            }
        }
        dtButtons.push(deleteButton)
        @endcan
let dtOverrideGlobals = {
buttons: dtButtons,
processing: true,
serverSide: true,
retrieve: true,
aaSorting: [],
ajax: {
url: window.location.href,
data: function(d) {
d.min = $('input[name=min_date]').val();
d.max = $('input[name=max_date]').val();
}
},
columns: [
{ data: 'placeholder', name: 'placeholder',searchable:false,orderable:false },
{data: 'DT_RowIndex', name: 'DT_RowIndex',searchable:false,orderable:false},
{ data: 'date', name: 'date' },
{ data: 'sub_category', name: 'sub_category',orderable:false},
{ data: 'amount', name: 'amount' },
{ data: 'bank_account', name: 'bank_account' },
{ data: 'detail', name: 'detail' },
@can('deposit_bank_statement')
{ data: 'bank_statement_id', name: 'bank_statement_id',
  searchable : false, orderable : false
},
@endcan
{ data: 'actions', name: '{{ trans('global.actions') }}' }
],
orderCellsTop: true,
order: [[ 2, 'desc' ]],
pageLength: 100,
drawCallback: function() {
   $('.select-bank').select2();
}
};
let table = $('.datatable-deposit').DataTable(dtOverrideGlobals);
$('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
$($.fn.dataTable.tables(true)).DataTable()
.columns.adjust();
});
// Event listener to the two range filtering inputs to redraw on input
$('.search-btn').on("click", function(e) {
e.preventDefault();
$('input[name=min_date]').attr('required',true);
$('input[name=max_date]').attr('required',true);
if($('input[name=min_date]').val() != '' && $('input[name=max_date]').val() != ''){
table.draw();
}
else{
toastr.error('Min & Max date both are required.');
}
});
});
$(".datatable-deposit").on('change','.select-bank',function(){
    var row = $(this).closest("tr");
    var rowid = +row.find("input.depositrow").val();
    var paymentid = $(this).val();

    // if(paymentid == ''){
    //     // alert('Please select user');
    //     return false;
    // }else{
        if (!confirm("Confirm this payment for this depoist?")) {
            $(this).val('');
            return false;
            //abort!
        }else{
            $.ajax({
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                },
                type : 'POST',
                dataType : 'json',
                url : '{{ route("admin.deposits.bankstatements") }}',
                data : {rowid : rowid, paymentid : paymentid},
                success : function(response){
                  if(response.status == "error"){
                      $('.select-bank').val('');
                      toastr.error(response.message);
                      return false;
                  }
                  toastr.success('Payment is confirmed for this deposit.');
                  setTimeout(function(){
                      window.location = window.location.href;
                  },1000);
                },
               error: function(response){
                    $.each(response.responseJSON.errors, function (index, value) {
                      toastr.error(value);

                    });
                }
            });
        }
    // }
});
</script>
@endsection
