@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.account.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('cruds.account.title') }}</li>
                    </ul>
                </div>
                @can('driveway_account_create')
                    <div class="col-auto float-right ml-auto">
                        <a href="{{ route('admin.driveway-accounts.create') }}" class="btn add-btn"> <i class="fa fa-plus"></i>{{ trans('global.add') }} {{ trans('cruds.account.title_singular') }}</a>
                    </div>
                @endcan
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.account.title_singular') }} {{ trans('global.list') }}
            </div>

            <div class="card-body">
                <div class="row filter-row">
                    <div class="col-sm-6 col-md-4 col-lg-4">
                        <div class="form-group form-focus">
                            <div class="cal-icon">
                                <input class="form-control floating datetimepicker" type="text" id="start_date">
                            </div>
                            <label class="focus-label">From</label>
                        </div>
                    </div>
                   <div class="col-sm-6 col-md-4 col-lg-4">
                        <div class="form-group form-focus">
                            <div class="cal-icon">
                                <input class="form-control floating datetimepicker" type="text" id="end_date">
                            </div>
                            <label class="focus-label">To</label>
                        </div>
                    </div>
                    <div class="col-sm-4 col-md-3 col-lg-3">
                        <div class="form-group">
                            <button class="btn btn-success" id="btnSearch">{{ trans('global.search') }}</button>
                            <a href="{{route('admin.driveway-accounts.index')}}" class="btn btn-info">{{ trans('global.reset') }}</a>
                        </div>
                    </div>
                </div>
                <table class=" table table-bordered table-hover ajaxTable datatable datatable-DrivewayAccount">
                    <thead>
                        <tr>
                            <th width="10">

                            </th>
                            <th>
                                {{__('ID')}}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.date') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.invoice_no') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.account_name') }}
                            </th>
                            <th>
                                {{ trans('cruds.account.fields.amount') }}
                            </th>
                            <th>
                                &nbsp;
                            </th>
                        </tr>
                    </thead>
                </table>
            </div>
        </div>
    </div>
</div>



@endsection
@section('scripts')
@parent
<script>
    $(function () {
        let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
        @can('driveway_account_delete')
        let deleteButtonTrans = '{{ trans('global.datatables.delete') }}';
        let deleteButton = {
        text: deleteButtonTrans,
        url: "{{ route('admin.driveway-accounts.massDestroy') }}",
        className: 'bg-inverse-danger',
        action: function (e, dt, node, config) {
            var ids = $.map(dt.rows({ selected: true }).data(), function (entry) {
                return entry.id
            });

            if (ids.length === 0) {
            alert('{{ trans('global.datatables.zero_selected') }}')

            return
            }

            if (confirm('{{ trans('global.areYouSure') }}')) {
            $.ajax({
                headers: {'x-csrf-token': _token},
                method: 'POST',
                url: config.url,
                data: { ids: ids, _method: 'DELETE' }})
                .done(function () { location.reload() })
            }
        }
        }
        dtButtons.push(deleteButton)
        @endcan

        let dtOverrideGlobals = {
        buttons: dtButtons,
        processing: true,
        serverSide: true,
        retrieve: true,
        aaSorting: [],
        ajax: {
            url: "{{route('admin.driveway-accounts.index')}}",
            data: function (d) {
                    d.startDate = $('#start_date').val();
                    d.endDate = $('#end_date').val();
                }
            },
        columns: [
            { data: 'placeholder', name: 'placeholder' },
            {data: 'DT_RowIndex', name: 'DT_RowIndex'},
            { data: 'date', name: 'date' },
            { data: 'invoice_no', name: 'invoice_no' },
            { data: 'account_name', name: 'account_name' },
            { data: 'amount', name: 'amount' },
            { data: 'actions', name: '{{ trans('global.actions') }}' }
        ],
        orderCellsTop: true,
        order: [[ 1, 'desc' ]],
        pageLength: 100,
        };
        let table = $('.datatable-DrivewayAccount').DataTable(dtOverrideGlobals);
        $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
            $($.fn.dataTable.tables(true)).DataTable()
                .columns.adjust();
        });

        $('#btnSearch').click(function (e) {
            e.preventDefault();
            table.draw();

        });

    });

</script>
@endsection
