@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.drivewaySheet.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.driveway-sheets.index')}}">{{trans('cruds.drivewaySheet.title_singular') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.driveway-sheets.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i> {{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">   
            @php
                $sheetdate = $date != null ? date('d/m/Y',strtotime($date)) : null;
                $day = $sheetdate != null ? date('d',strtotime($sheetdate)) : null;
            @endphp
            @include('partials.drivewayPartial')   
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.drivewaySheet.title_singular') }}
            </div>
            <div class="card-body">
                <form method="POST" class="driveway-form" action="{{ route('admin.driveway-sheets.store') }}" enctype="multipart/form-data">
                @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="date">{{ trans('cruds.drivewaySheet.fields.date') }}</label>
                                <input class="form-control date {{ $errors->has('date') ? 'is-invalid' : '' }}" type="text" name="date" id="date" value="{{$sheetdate}}" {{$sheetdate != null ? 'readonly' : ''}} required>
                                @if($errors->has('date'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('date') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.drivewaySheet.fields.date_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <table id="custom_table" class="table table-bordered">
                        <thead>
                            <th>{{ trans('cruds.pump.fields.pump') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.opening') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.closing') }}</th>
                            @foreach($fuels as $key => $fuel)
                                <th>{{ $fuel }}</th>
                            @endforeach
                        </thead>
                        <tbody>
                            @foreach($pumps as $key => $pump)
                            @php
                                $pump_fuel = $pump->pivot->fuel_id;
                                $prev_day = $drivesheet->where('pump_id',$pump->id)->where('fuel_id',$pump_fuel)->first();
                                $opening = !empty($prev_day) ? $prev_day->closing_balance : null;
                            @endphp
                                <tr class="driveway-stock">
                                    <td>
                                        <input type="hidden" name="fuel_id[{{$key}}]" value="{{$pump_fuel}}" readonly>
                                        <input type="hidden" class="stock-value" name="stock[{{$key}}]" value="{{ old('stock[$key]') }}" readonly>
                                        <input type="hidden" name="pump_id[{{$key}}]" value="{{$pump->id}}" readonly>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('pump_name') ? 'is-invalid' : ''}}" name="pump_name[{{$key}}]" value="{{$pump->pump}}" readonly>
                                            @if($errors->first('pump_name'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('pump_name') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.drivewaySheet.fields.pump_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="opening form-control {{ $errors->has('opening_balance') ? 'is-invalid' : ''}}" name="opening_balance[{{$key}}]" value="{{ old('opening_balance[$key]', $opening) }}" min="0" step="0.01" {{ $opening != null && $day != '01' && $day != null ? 'readonly' : ''}} required="">
                                            @if($errors->first('opening_balance'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('opening_balance') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.drivewaySheet.fields.opening_balance') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="closing form-control {{ $errors->has('closing_balance') ? 'is-invalid' : ''}}" name="closing_balance[{{$key}}]" value="{{ old('closing_balance[$key]') }}" min="0" step="0.01" required="">
                                            @if($errors->first('closing_balance'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('closing_balance') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.drivewaySheet.fields.closing_balance') }}</span>
                                        </div>
                                    </td>
                                    @foreach($fuels as $id => $fuel)
                                        <td>
                                            <div class="form-group small">
                                                <input type="text" class="form-control {{$pump_fuel == $id ? 'stock' : null}} {{ $errors->has('fuel_type') ? 'is-invalid' : ''}}" name="fuel_type[{{$key}}]" value="{{ old('fuel_type[$key]') }}" readonly>
                                                @if($errors->first('fuel_id'))
                                                    <div class="invalid-feedback">
                                                        {{ $errors->first('fuel_id') }}
                                                    </div>
                                                @endif
                                            </div>
                                        </td>
                                    @endforeach
                                </tr>
                            @endforeach
                            <tr>   
                                <td colspan="3"><b>{{ trans('cruds.fuelStock.fields.computer_sale') }}</b></td>
                                @foreach($fuels as $id => $fuel)                                                         
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="form-control {{ $errors->has('computer_sale') ? 'is-invalid' : ''}}" name="computer_sale[]" value="{{ old('computer_sale[$key]') }}" min="0" step="0.01">
                                            @if($errors->first('computer_sale'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('computer_sale') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.sale_helper') }}</span>
                                        </div>
                                    </td>
                                @endforeach
                            </tr>
                        </tbody>
                    </table>
                    <div class="card-header"> 
                        <u>{{ trans('global.add') }} {{ trans('cruds.fuelStock.title_singular') }}</u>
                    </div>
                    <table id="custom_table1" class="table table-bordered">
                        <thead>
                            <th>{{ trans('global.title') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.opening_stock') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.purchase') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.calculated_stock') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.closing_dips') }}</th>
                        </thead>
                        <tbody>
                            @foreach($fuels as $key => $fuel)
                                @php
                                    $fuel_prev_day = $fuelsheet->where('fuel_type',$key)->first();
                                    $fuel_opening = !empty($fuel_prev_day) ? $fuel_prev_day->closing_dips : null;
                                @endphp
                                <tr class="fuel-stock">
                                     <td>  
                                        <div class="form-group small">
                                            <input type="hidden" name="fuel_stock[]" value="{{$key}}" readonly>
                                            <input type="text" class="form-control {{ $errors->has('fuel_stock') ? 'is-invalid' : ''}}" value="{{$fuel}}" readonly>
                                        </div>
                                    </td>       
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="opening-stock form-control {{ $errors->has('opening_stock') ? 'is-invalid' : ''}}" name="opening_stock[]" value="{{ $fuel_opening != null && $day != '01' ? $fuel_opening : ''}}" {{ $fuel_opening != null && $day != '01' ? 'readonly' : ''}} min="0" step="0.01" required>
                                            @if($errors->first('opening_stock'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('opening_stock') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.opening_stock_helper') }}</span>
                                        </div>
                                    </td>                                    
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="purchase form-control {{ $errors->has('purchase') ? 'is-invalid' : ''}}" name="purchase[]" value="{{ old('purchase[$key]') }}" min="0" step="0.01">
                                            @if($errors->first('purchase'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('purchase') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.purchase_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="calculated-stock form-control {{ $errors->has('calculated_stock') ? 'is-invalid' : ''}}" name="calculated_stock[]" value="{{ old('calculated_stock[$key]') }}" min="0" step="0.01" readonly>
                                            @if($errors->first('calculated_stock'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('calculated_stock') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.calculated_stock_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="form-control {{ $errors->has('closing_dips') ? 'is-invalid' : ''}}" name="closing_dips[]" value="{{ old('closing_dips[$key]') }}" min="0" step="0.01"required>
                                            @if($errors->first('closing_dips'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('closing_dips') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.closing_dips_helper') }}</span>
                                        </div>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                    <!-- Save Button -->
                    <div class="form-group small">
                        <button class="btn btn-info" type="reset">
                            {{ trans('global.reset') }}
                        </button>
                        <button class="btn btn-primary" type="submit">
                            {{ trans('global.save') }}
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@endsection
@section('scripts')
<script>
    'use Strict';
    $(document).ready(function () {
        $('.driveway-stock').on('input', function (event) {
            let Num1 = Number($(this).find('.opening').val());
            let Num2 = Number($(this).find('.closing').val());
            // let amount = parseFloat($('#price').val());
            if ((Num2 !=0) && (Num1 !=0)) {
                var result = (Num2 - Num1).toFixed(2);
                $(this).find('.stock').val(result);
                $(this).find('.stock-value').val(result);
            }
        });
        $('.fuel-stock').on('input', function (event) {
            let Num1 = Number($(this).find('.opening-stock').val());
            let Num2 = Number($(this).find('.purchase').val());
            // let amount = parseFloat($('#price').val());
            var result = (Num2 + Num1).toFixed(2);
            $(this).find('.calculated-stock').val(result);
        });
    });
</script>
@endsection
