@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.drivewaySheet.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.driveway-sheets.index')}}">{{trans('cruds.drivewaySheet.title_singular') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.show')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.driveway-sheets.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i> {{ trans('global.back') }}</a>
                    @if($drivesheet->first()->is_approved == 0)
                    @can('driveway_sheet_edit')
                        <a class="btn add-btn" href="{{ route('admin.driveway-sheets.datewise_edit', $date) }}" title="Edit"><i class="la la-edit"></i> {{ trans('global.edit') }}</a>
                    @endcan
                    @endif
                </div>
            </div>
        </div>

        <div class="card">
            @include('partials.drivewayPartial')
            <div class="card-header">
                {{ trans('global.show') }} {{ trans('cruds.drivewaySheet.title') }}
            </div>

            <div class="card-body">
                <div class="form-group">
                    <table class="table table-striped table-hover datatable-driveway report-table">
                    @php
                        $sum = [];
                        $mechanical = [];
                        $fuelsale = 0;
                    @endphp
                    <thead>
                        <tr>
                            <th>{{ trans('cruds.pump.fields.pump') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.opening') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.closing') }}</th>
                             @foreach($fuels as $key => $fuel)
                                <th>{{ $fuel }}</th>
                            @endforeach
                            <th>{{ trans('global.total') }}</th>
                            <th>{{ trans('cruds.report.fuelSale') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($drivesheet as $key => $data)
                            @php
                                $fuelsale = $fuelsale + $data->stock_value;
                            @endphp
                            <tr>
                                <td>{{$data->pump->pump}}</td>
                                <td>{{number_format($data->opening_balance,2)}}</td>
                                <td>{{number_format($data->closing_balance,2)}}</td>
                                @foreach($fuels as $id => $fuel)
                                    <td>
                                        @if($data->fuel_id == $id)
                                            {{number_format($data->stock,2)}}
                                        @endif
                                    </td>
                                @endforeach
                                <td></td>
                                <td>{{number_format($data->stock_value,2)}}</td>
                            </tr>
                        @endforeach
                    </tbody>
                    @if(count($drivesheet) > 0)
                    <tfoot>
                        <tr class="highlight">
                            <td colspan="3" class="left"><strong>{{ trans('cruds.report.computerSale') }}</strong></td>
                            @foreach($fuels as $id => $fuel)
                                @php
                                    $sale[$id] = count($fuelstock) > 0 && !empty($fuelstock->where('fuel_type',$id)->first()) ? $fuelstock->where('fuel_type',$id)->first()->sale : 0;
                                @endphp
                                <td><b>{{number_format($sale[$id],2)}}</b></td>
                            @endforeach
                            <td><b>{{number_format(array_sum($sale),2)}}</b></td>
                            <td><b>{{number_format($fuelsale,2)}}</b></td>
                        </tr>
                        <tr>
                            <td colspan="3" class="left"><strong>{{ trans('cruds.report.mechanicalSale') }} {{ trans('cruds.report.inLtr') }}</strong></td>
                            @foreach($fuels as $id => $fuel)
                                @php
                                    $sum[$id] = $drivesheet->where('fuel_id',$id)->sum('stock');
                                @endphp
                                <td><b>{{number_format($sum[$id],2)}}</b></td>
                            @endforeach
                            <td><b>{{number_format(array_sum($sum),2)}}</b></td>
                            <td></td>
                        </tr>
                        <tr>
                            <td colspan="3" class="left"><strong>{{ trans('cruds.report.mechanicalValue') }}</strong></td>
                            @foreach($fuels as $id => $fuel)
                                @php
                                    $selling_price = $fuelprices->where('fuel_id',$id)->first();
                                    $price = $selling_price ? $selling_price->selling_price : '0';
                                    $mechanical[$id] = $sum[$id] * (float) $price;
                                @endphp
                                <td><b>{{number_format($mechanical[$id],2)}}</b></td>
                            @endforeach
                            <td><b>{{number_format(array_sum($mechanical),2)}}</b></td>
                            <td></td>
                        </tr>
                        <tr class="highlight">
                            <td colspan="3" class="left"><strong>{{ trans('cruds.report.difference') }} {{ trans('cruds.report.inLtr') }}</strong></td>
                            @foreach($fuels as $id => $fuel)
                                @php
                                    $diff[$id] = $sum[$id] - $sale[$id];
                                @endphp
                                <td><b>{{number_format($diff[$id],2)}}</b></td>
                            @endforeach
                            <td><b>{{number_format(array_sum($sum) - array_sum($sale),2)}}</b></td>
                            <td></td>
                        </tr>
                    </tfoot>
                    @endif
                </table>
                <h5 class="m-t-20 m-b-20"><u>{{ trans('cruds.fuelStock.title_singular') }} {{ trans('cruds.fuelStock.fields.control') }}</u></h5>
                <table class="table table-striped table-hover datatable-driveway report-table">
                    <thead>
                        <tr>
                            <th class="left">Fuel</th>
                            <th>{{ trans('cruds.fuelStock.fields.opening_stock') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.purchase') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.calculated_stock') }}</th>
                            <th>{{ trans('cruds.report.lessSale') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.closing_stock') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.closing_dips') }}</th>
                            <th>{{ trans('cruds.report.difference') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php
                            $opening_stock = 0;
                            $purchase = 0;
                            $cal_stock = 0;
                            $less_sale = 0;
                            $closing_dips = 0;
                            $closing_stock = 0;
                        @endphp
                        @foreach($fuelstock as $key => $data)
                            @php
                                $l_sale = $drivesheet->where('fuel_id',$data->fuel_type)->sum('stock');
                                $clos_stock = $data->stock - $l_sale;
                                $opening_stock += $data->opening_stock;
                                $purchase += $data->purchase;
                                $cal_stock += $data->stock;
                                $less_sale += $l_sale;
                                $closing_dips += $data->closing_dips;
                                $closing_stock += $clos_stock;
                            @endphp
                            <tr>
                            <tr>
                                <td class="left"><b>{{$data->fuel->fuel_name}}</b></td>
                                <td>{{number_format($data->opening_stock,2)}}</td>
                                <td>{{number_format($data->purchase,2)}}</td>
                                <td>{{number_format($data->stock,2)}}</td>
                                <td>{{number_format($l_sale,2)}}</td>
                                <td>{{number_format($clos_stock,2)}}</td>
                                <td>{{number_format($data->closing_dips,2)}}</td>
                                <td>{{number_format($data->closing_dips - $clos_stock,2)}}</td>
                            </tr>
                        @endforeach
                    </tbody>
                    @if(count($drivesheet) > 0 && count($fuelstock) > 0)
                    <tfoot>
                        <tr class="highlight">
                            <td class="left"><strong>Total</strong></td>
                            <td><b>{{number_format($opening_stock,2)}}</b></td>
                            <td><b>{{number_format($purchase,2)}}</b></td>
                            <td><b>{{number_format($cal_stock,2)}}</b></td>
                            <td><b>{{number_format($less_sale,2)}}</b></td>
                            <td><b>{{number_format($closing_stock,2)}}</b></td>
                            <td><b>{{number_format($closing_dips,2)}}</b></td>
                            <td><b>{{number_format($closing_dips - $closing_stock,2)}}</b></td>
                        </tr>
                    </tfoot>
                    @endif
                </table>
                </div>
            </div>
        </div>
    </div>
</div>



@endsection
