@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.fuelStock.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.fuel-stocks.index')}}">{{trans('cruds.fuelStock.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.fuel-stocks.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.fuelStock.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.fuel-stocks.store") }}" enctype="multipart/form-data">
                    @csrf
                    <div class="row">
                        <div class="col-lg-6">
                            {{-- Date --}}
                            <div class="form-group">
                                <label class="required" for="date">{{ trans('cruds.fuelStock.fields.date') }}</label>
                                <input class="form-control date {{ $errors->has('date') ? 'is-invalid' : '' }}" type="text" name="date"
                                    id="date" value="{{ old('date','') }}" required>
                                @if($errors->has('date'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('date') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.fuelStock.fields.date_helper') }}</span>
                            </div>
                            {{-- End Date --}}
                        </div>
                        <div class="col-lg-6">
                            <!-- Fuel Type -->
                            <div class="form-group">
                                <label class="required">{{ trans('cruds.fuelStock.fields.fuel_type') }}</label>
                                <select class="form-control {{ $errors->has('fuel_type') ? 'is-invalid' : '' }}" name="fuel_type"
                                    id="fuel_type" required>
                                    <option value disabled {{ old('fuel_type', null) === null ? 'selected' : '' }}>
                                        {{ trans('global.pleaseSelect') }}</option>
                                    @foreach($fuels as $fuel)
                                    <option value="{{ $fuel->id }}" {{ old('fuel_type', '') === (string) $fuel->id ? 'selected' : '' }}>
                                        {{ $fuel->fuel_name }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('fuel_type'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('fuel_type') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.fuelStock.fields.fuel_type_helper') }}</span>
                            </div>
                            {{-- End Fuel Type --}}
                        </div>
                        <div class="col-lg-6">
                            {{-- For Opening Stock --}}
                            <div class="form-group">
                                <label class="required" for="opening_stock">{{ trans('cruds.fuelStock.fields.opening_stock') }}</label>
                                <input class="form-control {{ $errors->has('opening_stock') ? 'is-invalid' : '' }}" type="text" name="opening_stock"
                                    id="opening_stock" value="{{ old('opening_stock','') }}" required>
                                @if($errors->has('opening_stock'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('opening_stock') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.fuelStock.fields.opening_stock_helper') }}</span>
                            </div>
                            {{-- End Opening Stock Control --}}
                        </div>
                        <div class="col-lg-6">
                            {{-- For Purchase  --}}
                            <div class="form-group">
                                <label for="purchase">{{ trans('cruds.fuelStock.fields.purchase') }}</label>
                                <input class="form-control {{ $errors->has('purchase') ? 'is-invalid' : '' }}" type="text" name="purchase"
                                    id="purchase" value="{{ old('purchase','') }}">
                                @if($errors->has('purchase'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('purchase') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.fuelStock.fields.opening_stock_helper') }}</span>
                            </div>
                            {{-- End Purchase --}}
                        </div>
                        <div class="col-lg-6">
                            {{-- For Stock --}}
                            <div class="form-group">
                                <label class="required" for="stock">{{ trans('cruds.fuelStock.fields.stock') }}</label>
                                <input class="form-control {{ $errors->has('stock') ? 'is-invalid' : '' }}" type="text" name="stock"
                                    id="stock" value="{{ old('stock','') }}" readonly required>
                                @if($errors->has('stock'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('stock') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.fuelStock.fields.stock_helper') }}</span>
                            </div>
                            {{-- End Stock Control --}}
                        </div>
                        <div class="col-lg-6">
                            {{-- For Closing DIPS --}}
                            <div class="form-group">
                                <label class="required" for="closing_dips">{{ trans('cruds.fuelStock.fields.closing_dips') }}</label>
                                <input class="form-control {{ $errors->has('closing_dips') ? 'is-invalid' : '' }}" type="text" name="closing_dips"
                                    id="closing_dips" value="{{ old('closing_dips','') }}" required>
                                @if($errors->has('closing_dips'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('closing_dips') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.fuelStock.fields.closing_dips_helper') }}</span>
                            </div>
                            {{-- End Closing DIPS Control --}}
                        </div>
                        <div class="col-lg-6">
                            {{-- For Computer Sales in liter --}}
                            <div class="form-group">
                                <label class="required" for="sale">{{ trans('cruds.fuelStock.fields.computer_sale') }}</label>
                                <input class="form-control {{ $errors->has('sale') ? 'is-invalid' : '' }}" type="text" name="sale"
                                    id="sale" value="{{ old('sale','') }}" required>
                                @if($errors->has('sale'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('sale') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.fuelStock.fields.sale_helper') }}</span>
                            </div>
                            {{-- End Computer Sales in liter Control --}}
                        </div>
                        <div class="col-lg-6">
                            {{-- For Water level --}}
                            <div class="form-group">
                                <label for="water_level">{{ trans('cruds.fuelStock.fields.water_level') }}</label>
                                <input class="form-control {{ $errors->has('sale') ? 'is-invalid' : '' }}" type="text" name="water_level"
                                    id="water_level" value="{{ old('water_level','') }}">
                                @if($errors->has('water_level'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('water_level') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.fuelStock.fields.water_level_helper') }}</span>
                            </div>
                            {{-- End Water level Control --}}
                        </div>
                        <div class="col-lg-8">
                            {{-- For Discription --}}
                            <div class="form-group">
                                <label for="description">{{ trans('cruds.fuelStock.fields.description') }}</label>
                                <textarea class="form-control {{ $errors->has('description') ? 'is-invalid' : '' }} CalculateMe" name="description" id="description">{{ old('description','') }}</textarea>
                                @if($errors->has('description'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('description') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sheelCard.fields.description_helper') }}</span>
                            </div>
                            {{-- End Discription --}}

                        <!-- Save Button -->
                        <div class="form-group">
                            <button class="btn btn-info" type="reset">
                                {{ trans('global.reset') }}
                            </button>
                            <button class="btn btn-primary" type="submit">
                                {{ trans('global.save') }}
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@endsection

@section('scripts')
<script>
    // Calculate

    'use Strict';
    $(document).ready(function () {
        $('#closing_dips').on('blur', function (event) {
            let Num1 = Number($('#opening_stock').val())
            let Num2 = Number($('#purchase').val());
            // let amount = parseFloat($('#price').val());
            if ((Num2 !=0) && (Num1 !=0)) {
                var result = (Num2 + Num1);
                return $("#stock").val(result);
            }
            else
            {
                return $("#stock").val(Num1);
            }
        });

        $('#purchase').on('input', function (event) {
            let Num1 = Number($('#opening_stock').val())
            let Num2 = Number($('#purchase').val());
            // let amount = parseFloat($('#price').val());
            if ((Num2 !=0) && (Num1 !=0)) {
                var result = (Num2 + Num1);
                return $("#stock").val(result);
            }
            else
            {
                return $("#stock").val(Num1);
            }
        });
        $('#opening_stock').on('input', function (event) {
            let Num1 = Number($('#opening_stock').val())
            let Num2 = Number($('#purchase').val());
            // let amount = parseFloat($('#price').val());
            if ((Num2 !=0) && (Num1 !=0)) {
                var result = (Num2 + Num1);
                return $("#stock").val(result);
            }
            else
            {
                return $("#stock").val(Num1);
            }
        });



    });

</script>
@endsection
