@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.sheelCard.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        {{-- <li class="breadcrumb-item"><a href="{{route('admin.speed-points.index')}}">{{trans('cruds.speedPoint.title') }}</a></li> --}}
                        <li class="breadcrumb-item active">{{ trans('cruds.sheelCard.title_singular') }}</li>
                    </ul>
                </div>
                @can('sheel_card_create')
                    <div class="col-auto float-right ml-auto">
                        <a href="{{ route('admin.sheel-cards.create') }}" class="btn add-btn"> <i class="fa fa-plus"></i>{{ trans('global.add') }} {{ trans('cruds.sheelCard.title_singular') }}</a>
                        <button class="btn add-btn" data-toggle="modal" data-target="#csvImportModal">
                            <i class="la la-upload"></i> {{ __('Import') }}
                        </button>
                        @include('csvImport.import', ['model' => 'SheelCard', 'route' => 'admin.sheel-cards.import','title' => trans('cruds.sheelCard.title')])
                    </div>
                @endcan
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.sheelCard.title_singular') }} {{ trans('global.list') }}
            </div>

            <div class="card-body">
                <table class=" table table-bordered datatable datatable-shell">
                    <thead>
                        <tr>
                            {{-- <th style="width: 10px;"></th> --}}
                            <th>{{__('ID')}}</th>
                            <th>{{ trans('cruds.sheelCard.fields.date') }}</th>
                            <th>{{trans('cruds.sheelCard.fields.dayTotal')}}</th>
                            <th>{{ trans('global.action') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php
                            $i = 1;
                        @endphp
                        @if (count($sheel_card) == 0)
                            <tr>
                                <td colspan="2" class="text-center">
                                    <span>No data available</span>
                                </td>
                            </tr>
                        @else
                            @foreach ($sheel_card as $key => $value)
                                <tr>
                                    {{-- <td></td> --}}
                                    <td>
                                        {{$i}}
                                    </td>
                                    <td>
                                        {{date('d-M-y',strtotime($value))}}
                                    </td>
                                    <td>{{$key?number_format($key,2):''}}</td>
                                    <td>
                                        @can('sheel_card_show')
                                        <a class="btn btn-primary btn-xs" href="{{route('admin.sheel-cards.show',$value)}}">
                                            <i class="la la-eye"></i>
                                        </a>
                                        @endcan
                                        @can('sheel_card_edit')
                                        <a class="btn btn-info btn-xs" href="{{route('admin.sheel-cards.edit',$value)}}">
                                            <i class="la la-edit"></i>
                                        </a>
                                        @endcan
                                        @can('sheel_card_delete')
                                        <form action="{{ route('admin.sheel-cards.destroy', $value) }}" method="POST" onsubmit="return confirm('{{ trans('global.areYouSure') }}');" style="display: inline-block;">
                                            <input type="hidden" name="_method" value="DELETE">
                                            <input type="hidden" name="_token" value="{{ csrf_token() }}">
                                            <button type="submit" class="btn btn-xs btn-danger"> <i class="la la-trash"></i> </button>
                                        </form>
                                    @endcan

                                    </td>
                                    @php
                                        $i++;
                                    @endphp
                                </tr>
                            @endforeach
                        @endif
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(function () {
            $.extend(true, $.fn.dataTable.defaults, {select:false,columnDefs:false});

            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('driveway_sheet_delete')
            let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
            let deleteButton = {
                text: deleteButtonTrans,
                url: "{{ route('admin.users.massDestroy') }}",
                className: 'bg-inverse-danger',
                action: function (e, dt, node, config) {
                var ids = $.map(dt.rows({ selected: true }).nodes(), function (entry) {
                    return $(entry).data('entry-id')
                });

                if (ids.length === 0) {
                    alert('{{ trans('global.datatables.zero_selected') }}')

                    return
                }

                if (confirm('{{ trans('global.areYouSure') }}')) {
                    $.ajax({
                    headers: {'x-csrf-token': _token},
                    method: 'POST',
                    url: config.url,
                    data: { ids: ids, _method: 'DELETE' }})
                    .done(function () { location.reload() })
                }
                }
            }
            dtButtons.push(deleteButton)
            @endcan

            $.extend(true, $.fn.dataTable.defaults, {
                orderCellsTop: true,
                order: [[ 0, 'asc' ]],
                pageLength: 100,
            });
            // let table = $('.datatable-shell').DataTable({ buttons: dtButtons })
            let table = $('.datatable-shell').DataTable({ buttons: false})
            $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
                $($.fn.dataTable.tables(true)).DataTable()
                    .columns.adjust();
            });
            $('div#sidebar').on('transitionend', function(e) {
                $($.fn.dataTable.tables(true)).DataTable().columns.adjust();
            })
            $(".buttons-select-all").hide();
            $(".buttons-select-none").hide();
        })
    </script>
@endsection
