@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.siteReg.title')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.site-registers.index')}}">{{trans('cruds.siteReg.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.site-registers.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.siteReg.title') }}
            </div>

            <div class="card-body">
                <form method="POST" class="site-form" action="{{ route("admin.site-registers.store") }}" enctype="multipart/form-data">
                    @csrf
                    <div class="row">
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="name">{{ trans('cruds.siteReg.name') }}</label>
                                <input class="form-control {{ $errors->has('name') ? 'is-invalid' : '' }}" type="text" name="name" id="fuel" value="{{ old('name', '') }}" required>
                                @if($errors->has('name'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('name') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.name_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="Type">{{ trans('cruds.siteReg.site_type') }}</label>
                                <select class="form-control select2 {{$errors->has('type')? 'is-invalid' : ''}}" name="type_id" id="type" value="{{old('type','')}}" required>
                                    <option value="">Select Type</option>
                                    @foreach ($types as $value)
                                        <option value="{{$value->id}}"> {{$value->name}} </option>
                                    @endforeach
                                </select>
                                @if($errors->has('type'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('type') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.type_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="country">{{ trans('cruds.siteReg.country') }}</label>
                                <select class="form-control select2 {{$errors->has('country')? 'is-invalid' : ''}}" name="country" id="country" value="{{old('country','')}}" required>
                                    <option value="">Select Country</option>
                                    @foreach ($countries as $value)
                                        <option value="{{$value->country}}"> {{$value->country}} </option>
                                    @endforeach
                                </select>
                                @if($errors->has('country'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('country') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.country_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="state">{{ trans('cruds.siteReg.state') }}</label>
                                <select class="form-control select2 {{$errors->has('state_id')? 'is-invalid' : ''}}" name="state_id" id="state" value="{{old('state','')}}" required>
                                    <option value="">Select State</option>
                                </select>
                                @if($errors->has('state'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('state_id') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.state_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="city">{{ trans('cruds.siteReg.city') }}</label>
                                <select class="form-control select2 {{$errors->has('city_id')? 'is-invalid' : ''}}" name="city_id" id="city" value="{{old('city','')}}" required>
                                    <option value="">Select City</option>
                                </select>
                                @if($errors->has('city'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('city_id') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.city_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label for="remarks">{{ trans('global.detail') }}</label>
                                <input class="form-control {{ $errors->has('remarks') ? 'is-invalid' : '' }}" type="textarea" name="remarks" value="{{ old('remarks', '') }}">
                                @if($errors->has('remarks'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('remarks') }}
                                    </div>
                                @endif
                            </div>
                        </div>

                        <div class="col-lg-12 m-t-10">
                            <h5><u>Add Pump & Fuels</u></h5>
                            <div class="row">
                                <div class="col-lg-3">
                                    <b>Pump No</b>
                                </div>
                                <div class="col-lg-3">
                                    <b>Fuel</b>
                                </div>
                                <div class="col-lg-2 text-right">
                                    <button title="Add new block" class="add_button btn btn-info"><i class="fa fa-plus"></i></button>
                                </div>
                            </div>
                            <div class="additional-block">
                                <div class="row add-new-block">
                                    <div class="col-lg-3">
                                        <div class="form-group">
                                            <select name="pump_ids[]" class="form-control"  style="width: 100%;">
                                                <option value="">Please Select</option>
                                                @foreach($pumps as $p)
                                                <option value="{{$p->id}}">{{$p->pump}}</option>
                                                @endforeach
                                            </select>
                                            <small class="text-danger">{{ $errors->first("pump_ids.*") }}</small>
                                        </div>
                                    </div>
                                    <div class="col-lg-3">
                                        <div class="form-group">
                                            <select name="fuel_ids[]" class="form-control"  style="width: 100%;">
                                                <option value="">Please Select</option>
                                                @foreach($fuels as $f)
                                                <option value="{{$f->id}}">{{$f->fuel_name}}</option>
                                                @endforeach
                                            </select>
                                            <small class="text-danger">{{ $errors->first("fuel_ids.*") }}</small>
                                        </div>
                                    </div>
                                    <div class="col-lg-2">
                                        <a href="#" class="hide-block remove_field btn btn-xs btn-danger"><i class="fa fa-close"></i></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-12">
                            <div class="form-group">
                                <button class="btn btn-info" type="reset">
                                    {{ trans('global.reset') }}
                                </button>
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>

                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@endsection
@section('scripts')
    <script type="text/javascript">
    </script>
@endsection
