@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.speedPoint.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>

                        <li class="breadcrumb-item active">{{trans('cruds.speedPoint.title') }}</li>
                    </ul>
                </div>
                @can('speed_point_create')
                    <div class="col-auto float-right ml-auto">
                        <a href="{{ route('admin.speed-points.create') }}" class="btn add-btn"> <i class="fa fa-plus"></i>{{ trans('global.add') }} {{ trans('cruds.speedPoint.title_singular') }}</a>
                        <button class="btn add-btn" data-toggle="modal" data-target="#csvImportModal">
                           <i class="la la-upload"></i> {{ __('Import') }}
                        </button>
                        @include('csvImport.import', ['model' => 'SpeedPoint', 'route' => 'admin.speedPoint.import','title' => trans('cruds.speedPoint.title')])
                    </div>
                @endcan
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.speedPoint.title_singular') }} {{ trans('global.list') }}
            </div>

            <div class="card-body">
              <div class="row filter-row">
                  <div class="col-sm-3 col-md-3">
                    <div class="form-group form-focus">
                      <div class="cal-icon">
                        <input class="form-control floating datetimepicker" name="min_date" type="text">
                      </div>
                      <label class="focus-label">From</label>
                    </div>
                  </div>
                  <div class="col-sm-3 col-md-3">
                    <div class="form-group form-focus">
                      <div class="cal-icon">
                        <input class="form-control floating date" name="max_date" type="text">
                      </div>
                      <label class="focus-label">To</label>
                    </div>
                  </div>
                  <div class="col-sm-2 col-md-3">
                    <a href="#" class="btn btn-success search-btn"> Search </a>
                    <a class="btn btn-info" href="{{ route('admin.speed-points.index') }}">Reset</a>
                  </div>
                </div>
                <table class=" table table-bordered table-hover ajaxTable datatable datatable-speedpoint">
                    <thead>
                        <tr>
                            {{-- <th width="10">

                            </th> --}}
                            <th>
                                {{__('ID')}}
                            </th>
                            <th>
                                {{ trans('cruds.speedPoint.fields.reconcilation_type') }}
                            </th>
                            <th>
                                {{ trans('cruds.speedPoint.fields.date') }}
                            </th>
                            <th>
                                {{ trans('cruds.speedPoint.fields.batch_no') }}
                            </th>
                            <th>
                                {{ trans('cruds.speedPoint.fields.bank_account') }}
                            </th>
                            <th>
                                {{ trans('cruds.speedPoint.fields.amount') }}
                            </th>
                            @can('speed_point_bank_statement')
                            <th>
                              {{ trans('cruds.speedPoint.fields.bank_statements') }}
                            </th>
                            @endcan
                            <th>
                                &nbsp;
                            </th>
                        </tr>
                    </thead>
                </table>
            </div>
        </div>
    </div>
</div>



@endsection
@section('scripts')
@parent
<script>
    $(function () {
  "use strict";
  $.extend(true, $.fn.dataTable.defaults, {select:false,columnDefs:false});
//   let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
@can('speed_point_delete')
  let deleteButtonTrans = '{{ trans('global.datatables.delete') }}';
  let deleteButton = {
    text: deleteButtonTrans,
    url: "{{ route('admin.speed-points.massDestroy') }}",
    className: 'bg-inverse-danger',
    action: function (e, dt, node, config) {
      var ids = $.map(dt.rows({ selected: true }).data(), function (entry) {
          return entry.id
      });

      if (ids.length === 0) {
        alert('{{ trans('global.datatables.zero_selected') }}')

        return
      }

      if (confirm('{{ trans('global.areYouSure') }}')) {
        $.ajax({
          headers: {'x-csrf-token': _token},
          method: 'POST',
          url: config.url,
          data: { ids: ids, _method: 'DELETE' }})
          .done(function () { location.reload() })
      }
    }
  }
//   dtButtons.push(deleteButton)
@endcan

  let dtOverrideGlobals = {
    // buttons: dtButtons,
    processing: true,
    serverSide: true,
    retrieve: true,
    aaSorting: [],
    ajax: {
      url: "{{ route('admin.speed-points.index') }}",
        data: function(d) {
            d.min = $('input[name=min_date]').val();
            d.max = $('input[name=max_date]').val();
        }
    },
    columns: [
        //  { data: 'placeholder', name: 'placeholder' ,searchable : false, orderable : false
        //     },
        {data: 'DT_RowIndex', name: 'DT_RowIndex',searchable : false, orderable : false
            },
        { data: 'reconcilation_type', name: 'reconcilation_type' },
        { data: 'date', name: 'date' },
        { data: 'batch_no', name: 'batch_no' },
        { data: 'bank_account_id', name: 'bank_account_id' },
        { data: 'total', name: 'total' },
        @can('speed_point_bank_statement')
            { data: 'bank_statement_id', name: 'bank_statement_id',searchable : false, orderable : false
            },
        @endcan
        { data: 'actions', name: '{{ trans('global.actions') }}',searchable : false, orderable : false
            },
    ],
    orderCellsTop: true,
    order: [[ 0, 'desc' ]],
    pageLength: 100,
    drawCallback: function() {
       $('.select-bank').select2();
    }
  };
  let table = $('.datatable-speedpoint').DataTable(dtOverrideGlobals);
  $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
      $($.fn.dataTable.tables(true)).DataTable()
          .columns.adjust();
  });

  // Event listener to the two range filtering inputs to redraw on input
  $('.search-btn').on("click", function(e) {
      e.preventDefault();
      $('input[name=min_date]').attr('required',true);
      $('input[name=max_date]').attr('required',true);
      if($('input[name=min_date]').val() != '' && $('input[name=max_date]').val() != ''){
          table.draw();
      }
      else{
          toastr.error('Min & Max date both are required.');
      }
  });
  $("body").on('click',".delete-speed",function(e){
      e.preventDefault();
      var date = $(this).data('date');
      var batch = $(this).data('batch');
      var machine = $(this).data('machine');
      if (!confirm("Are you sure do you want to delete it?")) {
          return false;
          //abort!
      }else{
          $.ajax({
              headers: {
                  'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
              },
              type : 'POST',
              dataType : 'json',
              url : '{{ route("admin.speed-points.delete") }}',
              data : {machine : machine, date : date, batch : batch},
              success : function(response){
                toastr.success('Speedpoints have been deleted.');
                setTimeout(function(){
                    window.location = "{{ route('admin.speed-points.index') }}";
                },1000);
              },
             error: function(response){
                $.each(response.responseJSON.errors, function (index, value) {
                  toastr.error(value);

                });
              }
          });
      }
  });
  $(".datatable-speedpoint").on('change','.select-bank',function(){
    var row = $(this).closest("tr");
    var batchid = +row.find("input.speedbatch").val();
    var machineid = +row.find("input.speedmachine").val();
    var paymentid = $(this).val();
    // if(paymentid == ''){
    //     // alert('Please select user');
    //     return false;
    // }else{
        if (!confirm("Confirm this payment for this speedpoint batch?")) {
            $(this).val('');
            return false;
            //abort!
        }else{
            $.ajax({
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                },
                type : 'POST',
                dataType : 'json',
                url : '{{ route("admin.speed-points.bankstatements") }}',
                data : {machineid : machineid, batchid : batchid, paymentid : paymentid},
                success : function(response){
                  if(response.status == "error"){
                      $('.select-bank').val('');
                      toastr.error(response.message);
                      return false;
                  }
                  toastr.success('Payment is confirmed for this speedpoint.');
                  setTimeout(function(){
                      window.location = "{{ route('admin.speed-points.index') }}";
                  },1000);
                },
               error: function(response){
                    $.each(response.responseJSON.errors, function (index, value) {
                      toastr.error(value);

                    });
                }
            });
        }
    // }
  });
  $(".buttons-select-all").hide();
  $(".buttons-select-none").hide();
});

</script>
@endsection
